### doc/emacs/Makefile.  Generated from Makefile.in by configure.

# Copyright (C) 1994, 1996-2014 Free Software Foundation, Inc.

# This file is part of GNU Emacs.

# GNU Emacs is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# GNU Emacs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.

SHELL = /bin/bash

# NB If you add any more configure variables,
# update the sed rules in the dist target below.

# Where to find the source code.  $(srcdir) will be the doc/emacs subdirectory
# of the source tree.  This is set by configure's `--srcdir' option.
srcdir=.

# Only for make dist.
version=24.4

## Where the output files go.
## Note that the setfilename command in the .texi files assumes this.
## This is a bit funny.  Because the info files are in the
## distribution tarfiles, they are always made in $scrdir/../../info,
## even for out-of-tree builds.
buildinfodir = $(srcdir)/../../info
# Directory with the (customized) texinfo.tex file.
texinfodir = $(srcdir)/../misc

prefix = /usr/local
datarootdir = ${prefix}/share
datadir = ${datarootdir}
PACKAGE_TARNAME = emacs
docdir = ${datarootdir}/doc/${PACKAGE_TARNAME}
dvidir = ${docdir}
htmldir = ${docdir}
pdfdir = ${docdir}
psdir = ${docdir}

MKDIR_P = /bin/mkdir -p

GZIP_PROG = /bin/gzip

HTML_OPTS = --no-split --html

INFO_EXT=.info
# Options used only when making info output.
# --no-split is only needed because of MS-DOS.
# For a possible alternative, see
# http://lists.gnu.org/archive/html/emacs-devel/2011-01/msg01182.html
INFO_OPTS=--no-split

INSTALL = /usr/bin/install -c
INSTALL_DATA = ${INSTALL} -m 644

# The makeinfo program is part of the Texinfo distribution.
# Use --force so that it generates output even if there are errors.
MAKEINFO = makeinfo
MAKEINFO_OPTS = --force --enable-encoding -I $(srcdir)

TEXI2DVI = texi2dvi
TEXI2PDF = texi2pdf
DVIPS = dvips


ENVADD = TEXINPUTS="$(srcdir):$(texinfodir):$(TEXINPUTS)" \
         MAKEINFO="$(MAKEINFO) $(MAKEINFO_OPTS)"

DVI_TARGETS = emacs.dvi emacs-xtra.dvi
HTML_TARGETS = emacs.html
PDF_TARGETS = emacs.pdf emacs-xtra.pdf
PS_TARGETS = emacs.ps emacs-xtra.ps

EMACS_XTRA= \
	${srcdir}/emacs-xtra.texi \
	$(srcdir)/arevert-xtra.texi \
	$(srcdir)/cal-xtra.texi \
	$(srcdir)/dired-xtra.texi \
	$(srcdir)/picture-xtra.texi \
	$(srcdir)/emerge-xtra.texi \
	$(srcdir)/vc-xtra.texi \
	$(srcdir)/vc1-xtra.texi \
	$(srcdir)/fortran-xtra.texi \
	$(srcdir)/msdog-xtra.texi

EMACSSOURCES= \
	${srcdir}/emacs.texi \
	${srcdir}/emacsver.texi \
	${srcdir}/doclicense.texi \
	${srcdir}/gpl.texi \
	${srcdir}/screen.texi \
	${srcdir}/commands.texi \
	${srcdir}/entering.texi \
	${srcdir}/basic.texi \
	${srcdir}/mini.texi \
	${srcdir}/m-x.texi \
	${srcdir}/help.texi \
	${srcdir}/mark.texi \
	${srcdir}/killing.texi \
	${srcdir}/regs.texi \
	${srcdir}/display.texi \
	${srcdir}/search.texi \
	${srcdir}/fixit.texi \
	${srcdir}/files.texi \
	${srcdir}/buffers.texi \
	${srcdir}/windows.texi \
	${srcdir}/frames.texi \
	${srcdir}/mule.texi \
	${srcdir}/modes.texi \
	${srcdir}/indent.texi \
	${srcdir}/text.texi \
	${srcdir}/programs.texi \
	${srcdir}/building.texi \
	${srcdir}/maintaining.texi \
	${srcdir}/abbrevs.texi \
	${srcdir}/sending.texi \
	${srcdir}/rmail.texi \
	${srcdir}/dired.texi \
	${srcdir}/calendar.texi \
	${srcdir}/misc.texi \
	${srcdir}/package.texi \
	${srcdir}/custom.texi \
	${srcdir}/trouble.texi \
	${srcdir}/cmdargs.texi \
	${srcdir}/xresources.texi \
	${srcdir}/anti.texi \
	${srcdir}/macos.texi \
	${srcdir}/msdog.texi \
	${srcdir}/gnu.texi \
	${srcdir}/glossary.texi \
	${srcdir}/ack.texi \
	${srcdir}/kmacro.texi \
	$(EMACS_XTRA)

## The info/ directory exists in release tarfiles but not the repository.
mkinfodir = @${MKDIR_P} ${buildinfodir}

.PHONY: info dvi html pdf ps

.SUFFIXES: .ps .dvi

.dvi.ps:
	$(DVIPS) -o $@ $<

info: $(buildinfodir)/emacs$(INFO_EXT)
dvi: $(DVI_TARGETS)
html: $(HTML_TARGETS)
pdf: $(PDF_TARGETS)
ps: $(PS_TARGETS)

# Note that all the Info targets build the Info files in srcdir.
# There is no provision for Info files to exist in the build directory.
# In a distribution of Emacs, the Info files should be up to date.
# Note: "<" is not portable in ordinary make rules.
$(buildinfodir)/emacs$(INFO_EXT): ${EMACSSOURCES}
	$(mkinfodir)
	$(MAKEINFO) $(MAKEINFO_OPTS) $(INFO_OPTS) -o $@ ${srcdir}/emacs.texi

emacs.dvi: ${EMACSSOURCES}
	$(ENVADD) $(TEXI2DVI) ${srcdir}/emacs.texi

emacs.pdf: ${EMACSSOURCES}
	$(ENVADD) $(TEXI2PDF) ${srcdir}/emacs.texi

emacs.html: ${EMACSSOURCES}
	$(MAKEINFO) $(MAKEINFO_OPTS) $(HTML_OPTS) -o $@ ${srcdir}/emacs.texi

emacs-xtra.dvi: $(EMACS_XTRA)
	$(ENVADD) $(TEXI2DVI) ${srcdir}/emacs-xtra.texi

emacs-xtra.pdf: $(EMACS_XTRA)
	$(ENVADD) $(TEXI2PDF) ${srcdir}/emacs-xtra.texi

.PHONY: mostlyclean clean distclean maintainer-clean infoclean

## Temp files.
mostlyclean:
	rm -f *.aux *.log *.toc *.cp *.cps *.fn *.fns *.ky *.kys \
	  *.op *.ops *.pg *.pgs *.tp *.tps *.vr *.vrs

## Products not in the release tarfiles.
clean: mostlyclean
	rm -f $(DVI_TARGETS) $(HTML_TARGETS) $(PDF_TARGETS) $(PS_TARGETS)
	rm -f emacs-manual-${version}.tar*

distclean: clean
	rm -f Makefile

## In the standalone tarfile, the clean rule runs this.
infoclean:
	-cd $(buildinfodir) && rm -f emacs$(INFO_EXT) emacs$(INFO_EXT)-[1-9] emacs$(INFO_EXT)-[1-9][0-9]

maintainer-clean: distclean infoclean

.PHONY: dist

## Make a standalone tarfile of the Emacs manual sources.
## The [c] is a dumb way to prevent configure expanding it.
## TODO this is getting increasingly lengthy; not sure it is worth keeping.
dist:
	rm -rf emacs-manual-${version}
	mkdir emacs-manual-${version}
	cp ${srcdir}/*.texi ${texinfodir}/texinfo.tex \
	  ${srcdir}/ChangeLog* emacs-manual-${version}/
	sed -e 's/@sr[c]dir@/./' -e 's/^\(texinfodir *=\).*/\1 ./' \
	  -e 's/^\(buildinfodir *=\).*/\1 ./' \
	  -e 's/^\(clean:.*\)/\1 infoclean/' \
	  -e "s/@ver[s]ion@/${version}/" \
	  -e 's/@MAKE[I]NFO@/makeinfo/' -e 's/@MK[D]IR_P@/mkdir -p/' \
	  -e 's/@IN[F]O_EXT@/.info/' -e 's/@IN[F]O_OPTS@//' \
	  -e 's|@SH[E]LL@|/bin/bash|' \
	  -e 's|@[p]refix@|/usr/local|' \
	  -e 's|@[d]atarootdir@|$${prefix}/share|' \
	  -e 's|@[d]atadir@|$${datarootdir}|' \
	  -e 's|@[P]ACKAGE_TARNAME@|emacs|' \
	  -e 's|@[d]ocdir@|$${datarootdir}/doc/$${PACKAGE_TARNAME}|' \
	  -e 's|@[d]vidir@|$${docdir}|' \
	  -e 's|@[h]tmldir@|$${docdir}|' \
	  -e 's|@[p]dfdir@|$${docdir}|' \
	  -e 's|@[p]sdir@|$${docdir}|' \
	  -e 's|@[G]ZIP_PROG@|gzip|' \
	  -e 's|@IN[S]TALL@|install -c|' \
	  -e 's|@IN[S]TALL_DATA@|$${INSTALL} -m 644|' \
	  -e '/@[c]onfigure_input@/d' \
	  ${srcdir}/Makefile.in > emacs-manual-${version}/Makefile
	@if grep '@[a-zA-Z_]*@' emacs-manual-${version}/Makefile; then \
	  echo "Unexpanded configure variables in Makefile?" 1>&2; exit 1; \
	fi
	tar -cf emacs-manual-${version}.tar emacs-manual-${version}
	rm -rf emacs-manual-${version}


.PHONY: install-dvi install-html install-pdf install-ps install-doc

install-dvi: dvi
	umask 022; $(MKDIR_P) "$(DESTDIR)$(dvidir)"
	$(INSTALL_DATA) $(DVI_TARGETS) "$(DESTDIR)$(dvidir)"
install-html: html
	umask 022; $(MKDIR_P) "$(DESTDIR)$(htmldir)"
	$(INSTALL_DATA) $(HTML_TARGETS) "$(DESTDIR)$(htmldir)"
install-pdf: pdf
	 umask 022;$(MKDIR_P) "$(DESTDIR)$(pdfdir)"
	$(INSTALL_DATA) $(PDF_TARGETS) "$(DESTDIR)$(pdfdir)"
install-ps: ps
	umask 022; $(MKDIR_P) "$(DESTDIR)$(psdir)"
	for file in $(PS_TARGETS); do \
	  $(INSTALL_DATA) $${file} "$(DESTDIR)$(psdir)"; \
	  [ -n "${GZIP_PROG}" ] || continue; \
	  rm -f "$(DESTDIR)$(psdir)/$${file}.gz"; \
	  ${GZIP_PROG} -9n "$(DESTDIR)$(psdir)/$${file}"; \
	done

## Top-level Makefile installs the info pages.
install-doc: install-dvi install-html install-pdf install-ps


.PHONY: uninstall-dvi uninstall-html uninstall-pdf uninstall-ps uninstall-doc

uninstall-dvi:
	for file in $(DVI_TARGETS); do \
	  rm -f "$(DESTDIR)$(dvidir)/$${file}"; \
	done
uninstall-html:
	for file in $(HTML_TARGETS); do \
	  rm -f "$(DESTDIR)$(htmldir)/$${file}"; \
	done
uninstall-ps:
	ext= ; [ -n "${GZIP_PROG}" ] && ext=.gz; \
	for file in $(PS_TARGETS); do \
	  rm -f "$(DESTDIR)$(psdir)/$${file}$${ext}"; \
	done
uninstall-pdf:
	for file in $(PDF_TARGETS); do \
	  rm -f "$(DESTDIR)$(pdfdir)/$${file}"; \
	done

uninstall-doc: uninstall-dvi uninstall-html uninstall-pdf uninstall-ps


### Makefile ends here
