### doc/lispintro/Makefile.  Generated from Makefile.in by configure.

# Copyright (C) 1994-1999, 2001-2014 Free Software Foundation, Inc.

# This file is part of GNU Emacs.

# GNU Emacs is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# GNU Emacs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.

SHELL = /bin/bash

# NB If you add any more configure variables,
# update the sed rules in the dist target below.
srcdir = .
version=24.4

buildinfodir = $(srcdir)/../../info
# Directory with the (customized) texinfo.tex file.
texinfodir = $(srcdir)/../misc
# Directory with emacsver.texi.
emacsdir =  $(srcdir)/../emacs

prefix = /usr/local
datarootdir = ${prefix}/share
datadir = ${datarootdir}
PACKAGE_TARNAME = emacs
docdir = ${datarootdir}/doc/${PACKAGE_TARNAME}
dvidir = ${docdir}
htmldir = ${docdir}
pdfdir = ${docdir}
psdir = ${docdir}

MKDIR_P = /bin/mkdir -p

GZIP_PROG = /bin/gzip

HTML_OPTS = --no-split --html

INFO_EXT=.info
# Options used only when making info output.
INFO_OPTS=--no-split

INSTALL = /usr/bin/install -c
INSTALL_DATA = ${INSTALL} -m 644

MAKEINFO = makeinfo
MAKEINFO_OPTS = --force -I $(emacsdir) -I $(srcdir)
TEXI2DVI = texi2dvi
TEXI2PDF = texi2pdf
DVIPS = dvips

ENVADD = TEXINPUTS="$(srcdir):$(texinfodir):$(emacsdir):$(TEXINPUTS)" \
         MAKEINFO="$(MAKEINFO) $(MAKEINFO_OPTS)"

DVI_TARGETS = emacs-lisp-intro.dvi
HTML_TARGETS = emacs-lisp-intro.html
PDF_TARGETS = emacs-lisp-intro.pdf
PS_TARGETS = emacs-lisp-intro.ps

mkinfodir = @${MKDIR_P} ${buildinfodir}

srcs = ${srcdir}/emacs-lisp-intro.texi ${srcdir}/doclicense.texi \
  ${emacsdir}/emacsver.texi

.PHONY: info dvi html pdf ps

.SUFFIXES: .ps .dvi

.dvi.ps:
	$(DVIPS) -o $@ $<

info: ${buildinfodir}/eintr$(INFO_EXT)

dvi: $(DVI_TARGETS)
html: $(HTML_TARGETS)
pdf: $(PDF_TARGETS)
ps: $(PS_TARGETS)

# The file name eintr must fit within 5 characters, to allow for
# -NN extensions to fit into DOS 8+3 limits without clashing.
# Note: "<" is not portable in ordinary make rules.
${buildinfodir}/eintr$(INFO_EXT): ${srcs}
	$(mkinfodir)
	$(MAKEINFO) $(MAKEINFO_OPTS) $(INFO_OPTS) -o $@ ${srcdir}/emacs-lisp-intro.texi

emacs-lisp-intro.dvi: ${srcs}
	$(ENVADD) $(TEXI2DVI) ${srcdir}/emacs-lisp-intro.texi

emacs-lisp-intro.pdf: ${srcs}
	$(ENVADD) $(TEXI2PDF) ${srcdir}/emacs-lisp-intro.texi

emacs-lisp-intro.html: ${srcs}
	$(MAKEINFO) $(MAKEINFO_OPTS) $(HTML_OPTS) -o $@ ${srcdir}/emacs-lisp-intro.texi

.PHONY: mostlyclean clean distclean maintainer-clean infoclean

mostlyclean:
	rm -f *.aux *.log *.toc *.cp *.cps *.fn *.fns *.ky *.kys \
	  *.op *.ops *.pg *.pgs *.tp *.tps *.vr *.vrs

clean: mostlyclean
	rm -f $(DVI_TARGETS) $(HTML_TARGETS) $(PDF_TARGETS) $(PS_TARGETS)
	rm -f emacs-lispintro-${version}.tar*

distclean: clean
	rm -f Makefile

infoclean:
	-cd $(buildinfodir) && rm -f eintr$(INFO_EXT) eintr$(INFO_EXT)-[1-9]

maintainer-clean: distclean infoclean

.PHONY: dist

dist:
	rm -rf emacs-lispintro-${version}
	mkdir emacs-lispintro-${version}
	cp ${srcdir}/*.texi ${srcdir}/*.eps ${srcdir}/*.pdf \
	  ${texinfodir}/texinfo.tex ${emacsdir}/emacsver.texi \
	  ${srcdir}/ChangeLog* ${srcdir}/README emacs-lispintro-${version}/
	sed -e 's/@sr[c]dir@/./' -e 's/^\(texinfodir *=\).*/\1 ./' \
	  -e 's/^\(emacsdir *=\).*/\1 ./' \
	  -e 's/^\(buildinfodir *=\).*/\1 ./' \
	  -e 's/^\(clean:.*\)/\1 infoclean/' \
	  -e "s/@ver[s]ion@/${version}/" \
	  -e 's/@MAKE[I]NFO@/makeinfo/' -e 's/@MK[D]IR_P@/mkdir -p/' \
	  -e 's/@IN[F]O_EXT@/.info/' -e 's/@IN[F]O_OPTS@//' \
	  -e 's|@SH[E]LL@|/bin/bash|' \
	  -e 's|@[p]refix@|/usr/local|' \
	  -e 's|@[d]atarootdir@|$${prefix}/share|' \
	  -e 's|@[d]atadir@|$${datarootdir}|' \
	  -e 's|@[P]ACKAGE_TARNAME@|emacs|' \
	  -e 's|@[d]ocdir@|$${datarootdir}/doc/$${PACKAGE_TARNAME}|' \
	  -e 's|@[d]vidir@|$${docdir}|' \
	  -e 's|@[h]tmldir@|$${docdir}|' \
	  -e 's|@[p]dfdir@|$${docdir}|' \
	  -e 's|@[p]sdir@|$${docdir}|' \
	  -e 's|@[G]ZIP_PROG@|gzip|' \
	  -e 's|@IN[S]TALL@|install -c|' \
	  -e 's|@IN[S]TALL_DATA@|$${INSTALL} -m 644|' \
	  -e '/@[c]onfigure_input@/d' \
	  ${srcdir}/Makefile.in > emacs-lispintro-${version}/Makefile
	@if grep '@[a-zA-Z_]*@' emacs-lispintro-${version}/Makefile; then \
	  echo "Unexpanded configure variables in Makefile?" 1>&2; exit 1; \
	fi
	tar -cf emacs-lispintro-${version}.tar emacs-lispintro-${version}
	rm -rf emacs-lispintro-${version}


.PHONY: install-dvi install-html install-pdf install-ps install-doc

install-dvi: dvi
	umask 022; $(MKDIR_P) "$(DESTDIR)$(dvidir)"
	$(INSTALL_DATA) $(DVI_TARGETS) "$(DESTDIR)$(dvidir)"
install-html: html
	umask 022; $(MKDIR_P) "$(DESTDIR)$(htmldir)"
	$(INSTALL_DATA) $(HTML_TARGETS) "$(DESTDIR)$(htmldir)"
install-pdf: pdf
	 umask 022;$(MKDIR_P) "$(DESTDIR)$(pdfdir)"
	$(INSTALL_DATA) $(PDF_TARGETS) "$(DESTDIR)$(pdfdir)"
install-ps: ps
	umask 022; $(MKDIR_P) "$(DESTDIR)$(psdir)"
	for file in $(PS_TARGETS); do \
	  $(INSTALL_DATA) $${file} "$(DESTDIR)$(psdir)"; \
	  [ -n "${GZIP_PROG}" ] || continue; \
	  rm -f "$(DESTDIR)$(psdir)/$${file}.gz"; \
	  ${GZIP_PROG} -9n "$(DESTDIR)$(psdir)/$${file}"; \
	done

## Top-level Makefile installs the info pages.
install-doc: install-dvi install-html install-pdf install-ps


.PHONY: uninstall-dvi uninstall-html uninstall-pdf uninstall-ps uninstall-doc

uninstall-dvi:
	for file in $(DVI_TARGETS); do \
	  rm -f "$(DESTDIR)$(dvidir)/$${file}"; \
	done
uninstall-html:
	for file in $(HTML_TARGETS); do \
	  rm -f "$(DESTDIR)$(htmldir)/$${file}"; \
	done
uninstall-ps:
	ext= ; [ -n "${GZIP_PROG}" ] && ext=.gz; \
	for file in $(PS_TARGETS); do \
	  rm -f "$(DESTDIR)$(psdir)/$${file}$${ext}"; \
	done
uninstall-pdf:
	for file in $(PDF_TARGETS); do \
	  rm -f "$(DESTDIR)$(pdfdir)/$${file}"; \
	done

uninstall-doc: uninstall-dvi uninstall-html uninstall-pdf uninstall-ps


### Makefile ends here
