### leim/Makefile.  Generated from Makefile.in by configure.

# Copyright (C) 1997-2014 Free Software Foundation, Inc.
# Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
#   2006, 2007, 2008, 2009, 2010, 2011
#   National Institute of Advanced Industrial Science and Technology (AIST)
#   Registration Number H14PRO021

# This file is part of GNU Emacs.

# GNU Emacs is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# GNU Emacs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.

SHELL = /bin/bash

# Here are the things that we expect ../configure to edit.
srcdir=.

# Where the generated files go.
leimdir = ${srcdir}/../lisp/leim

# Which Emacs to use to convert TIT files to Emacs Lisp files,
# and generate the file leim-list.el.
EMACS = ../src/emacs

# How to run Emacs.
# Prevent any setting of EMACSLOADPATH in user environment causing problems.
RUN_EMACS = EMACSLOADPATH= '$(EMACS)' -batch --no-site-file --no-site-lisp

MKDIR_P = /bin/mkdir -p

# Files generated from TIT dictionaries for Chinese GB character set.
TIT_GB=\
	${leimdir}/quail/CCDOSPY.el	\
	${leimdir}/quail/Punct.el	\
	${leimdir}/quail/QJ.el		\
	${leimdir}/quail/SW.el		\
	${leimdir}/quail/TONEPY.el

# Files generated from TIT dictionaries for Chinese BIG5 character set.
TIT_BIG5=\
	${leimdir}/quail/4Corner.el	\
	${leimdir}/quail/ARRAY30.el	\
	${leimdir}/quail/ECDICT.el	\
	${leimdir}/quail/ETZY.el	\
	${leimdir}/quail/Punct-b5.el	\
	${leimdir}/quail/PY-b5.el	\
	${leimdir}/quail/QJ-b5.el	\
	${leimdir}/quail/ZOZY.el

CHINESE_TIT=${TIT_GB} ${TIT_BIG5}

MISC= \
	${leimdir}/quail/tsang-b5.el	\
	${leimdir}/quail/quick-b5.el	\
	${leimdir}/quail/tsang-cns.el	\
	${leimdir}/quail/quick-cns.el	\
	${leimdir}/quail/PY.el		\
	${leimdir}/quail/ZIRANMA.el	\
	${leimdir}/quail/CTLau.el	\
	${leimdir}/quail/CTLau-b5.el

## The generated .el files.
TIT_MISC=${CHINESE_TIT} ${MISC}

all: ${leimdir}/leim-list.el ${leimdir}/ja-dic/ja-dic.el
.PHONY: all

TIT_SOURCES= \
	${srcdir}/CXTERM-DIC/4Corner.tit \
	${srcdir}/CXTERM-DIC/ARRAY30.tit \
	${srcdir}/CXTERM-DIC/CCDOSPY.tit \
	${srcdir}/CXTERM-DIC/ECDICT.tit \
	${srcdir}/CXTERM-DIC/ETZY.tit \
	${srcdir}/CXTERM-DIC/PY-b5.tit \
	${srcdir}/CXTERM-DIC/Punct-b5.tit \
	${srcdir}/CXTERM-DIC/Punct.tit \
	${srcdir}/CXTERM-DIC/QJ-b5.tit \
	${srcdir}/CXTERM-DIC/QJ.tit \
	${srcdir}/CXTERM-DIC/SW.tit \
	${srcdir}/CXTERM-DIC/TONEPY.tit \
	${srcdir}/CXTERM-DIC/ZOZY.tit

${CHINESE_TIT}: changed.tit
	@true

## The changed.* files act to serialize this part of the build.
## A single Emacs invocation creates all the CHINESE_TIT files.
## Otherwise in a parallel build multiple Emacs instances could
## interfere with each other.  If we used GNU make we could probably
## parallelize this without the need for an explicit rule for each
## file.  Something like the pattern rule:
## quail/%.el: CXTERM-DIC/%.tit
## It doesn't seem possible to do this with VPATH and suffix rules.
changed.tit: ${TIT_SOURCES}
	@${MKDIR_P} ${leimdir}/quail
	${RUN_EMACS} -l titdic-cnv \
	  -f batch-titdic-convert -dir ${leimdir}/quail ${srcdir}/CXTERM-DIC
	echo "changed" > $@

MISC_SOURCES= \
	${srcdir}/MISC-DIC/CTLau-b5.html \
	${srcdir}/MISC-DIC/CTLau.html \
	${srcdir}/MISC-DIC/cangjie-table.b5 \
	${srcdir}/MISC-DIC/cangjie-table.cns \
	${srcdir}/MISC-DIC/pinyin.map \
	${srcdir}/MISC-DIC/ziranma.cin

${MISC}: changed.misc
	@true

changed.misc: ${MISC_SOURCES}
	@${MKDIR_P} ${leimdir}/quail
	${RUN_EMACS} -l titdic-cnv \
	  -f batch-miscdic-convert -dir ${leimdir}/quail ${srcdir}/MISC-DIC
	echo "changed" > $@

.PHONY: leim-list.el
leim-list.el: ${leimdir}/leim-list.el

${leimdir}/leim-list.el: ${TIT_MISC} ${srcdir}/leim-ext.el
	rm -f $@
	${RUN_EMACS} -l international/quail \
	  --eval "(update-leim-list-file (unmsys--file-name \"${leimdir}\"))"
	sed -n -e '/^[^;]/p' -e 's/^;\(;*\)inc /;\1 /p' < ${srcdir}/leim-ext.el >> $@

${leimdir}/ja-dic/ja-dic.el: $(srcdir)/SKK-DIC/SKK-JISYO.L
	@$(MKDIR_P) $(leimdir)/ja-dic
	$(RUN_EMACS) -batch -l ja-dic-cnv \
	  -f batch-skkdic-convert -dir "$(leimdir)/ja-dic" \
	  "$(srcdir)/SKK-DIC/SKK-JISYO.L"

.PHONY: bootstrap-clean distclean maintainer-clean extraclean

bootstrap-clean:
	rm -f ${TIT_MISC} ${leimdir}/leim-list.el changed.tit changed.misc

distclean:
	rm -f Makefile

maintainer-clean: distclean bootstrap-clean

## We do not delete ja-dic, even in a bootstrap, because it rarely
## changes and is slow to regenerate.
## TODO? Could consider doing the same with TIT_MISC, though those
## are much faster to generate.
extraclean:
	rm -rf ${leimdir}/ja-dic

### Makefile.in ends here
