# Copyright (C) 2002-2014  Free Software Foundation, Inc.
#      Written by Werner Lemberg <wl@gnu.org>
#
# This file is part of groff.
#
# groff is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# groff is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# These may be overridden if cross-compiling.
GROFFBIN=$(top_builddir)/src/roff/groff/groff
GROFF_BIN_PATH=`echo $(groff_bin_dirs) | sed -e 's|  *|$(SH_SEP)|g'`

groff_bin_dirs=\
  $(top_builddir)/src/roff/groff \
  $(top_builddir)/src/roff/troff \
  $(top_builddir)/src/preproc/preconv \
  $(top_builddir)/src/preproc/pic \
  $(top_builddir)/src/preproc/eqn \
  $(top_builddir)/src/preproc/tbl \
  $(top_builddir)/src/preproc/grn \
  $(top_builddir)/src/preproc/refer \
  $(top_builddir)/src/preproc/soelim \
  $(top_builddir)/src/preproc/html \
  $(top_builddir)/src/devices/grops \
  $(top_builddir)/src/devices/gropdf \
  $(top_builddir)/src/devices/grohtml

FFLAG=-F$(top_builddir)/font -F$(top_srcdir)/font
TFLAG=-M$(top_builddir)/tmac -M$(top_srcdir)/tmac

GROFF=\
  sed -e "s;@VERSION@;$(version)$(revision);" $< \
  | GROFF_COMMAND_PREFIX= \
    GROFF_BIN_PATH="$(GROFF_BIN_PATH)" \
    $(GROFFBIN) $(TFLAG) $(FFLAG) -Upet -ww

DOCFILES=\
  meref.me \
  meintro.me \
  meintro_fr.me \
  pic.ms

PROCESSEDDOCFILES=\
  meref.ps \
  meintro.ps \
  meintro_fr.ps \
  pic.ps

HTMLDOCFILES=\
  pic.html

HTMLDOCFILESALL=\
  pic*.html

HTMLDOCIMAGEFILES=\
  pic*

EXAMPLEFILES=\
  webpage.ms \
  groff.css \
  grnexmpl.g \
  grnexmpl.me

PROCESSEDEXAMPLEFILES=\
  webpage.ps \
  grnexmpl.ps

HTMLEXAMPLEFILES=\
  webpage.html

HTMLEXAMPLEFILESALL=\
  webpage*.html

HTMLEXAMPLEIMAGEFILES=\
  webpage*

imagedir=img
htmldocimagedir=$(htmldocdir)/$(imagedir)
exampleimagedir=$(exampledir)/$(imagedir)

MOSTLYCLEANADD=\
  $(PROCESSEDDOCFILES) \
  $(PROCESSEDEXAMPLEFILES) \
  $(HTMLEXAMPLEFILESALL) \
  $(HTMLDOCFILESALL) \
  groff.aux groff.cp* groff.dvi groff.es* groff.fn* groff.html groff.ky* \
  groff.log groff.ma* groff.op* groff.pdf groff.pg* groff.ps groff.rq* \
  groff.st* groff.toc groff.tp groff.vr* \
  examples.stamp

MOSTLYCLEANDIRADD=\
  $(imagedir)

MOSTLYCLEANNOTSRCDIRADD=\
  groff.css \
  grnexmpl.g \
  groff.info \
  groff-*.info \
  gnu.eps

RM=rm -f

.SUFFIXES: .me .ms .ps .html

# For simplicity, we always call preconv, grn, and eqn.
.me.ps:
	$(GROFF) -k -Tps -ge -me >$@

.ms.html:
	$(GROFF) -P-p -P-b -P-I`basename $< | sed -e 's|.ms$$||'` \
	         -P-D$(imagedir) -P-V -Thtml -ms >$@
.ms.ps:
	$(GROFF) -Tps -ms -mwww >$@

all: $(make_otherdoc) \
     $(make_infodoc) \
     $(make_htmldoc) \
     $(make_examples) \
     $(make_htmlexamples)

otherdoc: $(PROCESSEDDOCFILES)
infodoc: groff.info
htmldoc: $(HTMLDOCFILES)

examples: examples.stamp $(PROCESSEDEXAMPLEFILES)

html_examples: $(HTMLEXAMPLEFILES)

examples.stamp: grnexmpl.g groff.css gnu.eps
	test -f grnexmpl.g || cp $(srcdir)/grnexmpl.g .
	test -f groff.css || cp $(srcdir)/groff.css .
	if test ! -f gnu.eps; then \
	  if test -f $(srcdir)/gnu.eps; then \
	    cp $(srcdir)/gnu.eps .; \
	  elif test -f $(top_builddir)/contrib/pdfmark/gnu.eps; then \
	    cp $(top_builddir)/contrib/pdfmark/gnu.eps .; \
	  fi; \
	fi
	echo timestamp > $@

groff.info: groff.texinfo
	$(MAKEINFO) --enable-encoding -I$(srcdir) $(srcdir)/groff.texinfo

gnu.eps: gnu.xpm
	xpmtoppm $(srcdir)/gnu.xpm | pnmdepth 15 \
	  | $(pnmtops_nosetpage) -noturn -rle >$@

pic.html: pic.ms
	$(GROFF) -P-p -P-I`basename $< | sed -e 's|.ms$$||'` \
	         -P-D$(imagedir) -P-j`basename $< | sed -e 's|.ms$$||'` \
	         -Thtml -P-V -ms >$@

webpage.html: webpage.ms gnu.eps groff.css
	$(GROFF) -P-j`basename $< | sed -e 's|.ms$$||'` \
	         -P-nrpb -P-I`basename $< | sed -e 's|.ms$$||'` \
	         -P-D$(imagedir) -Thtml -ms >$@

webpage.ps: gnu.eps

grnexmpl.ps: grnexmpl.me grnexmpl.g

distfiles: groff.info gnu.eps

install_data: install_always $(make_install_otherdoc) \
	      $(make_install_infodoc) $(make_install_htmldoc) \
	      $(make_install_examples)

install_always:
	-test -d $(DESTDIR)$(docdir) || $(mkinstalldirs) $(DESTDIR)$(docdir)

install_otherdoc: install_always $(DOCFILES) $(PROCESSEDDOCFILES)
	for f in $(DOCFILES); do \
	  $(RM) $(DESTDIR)$(docdir)/$$f; \
	  $(INSTALL_DATA) $(srcdir)/$$f $(DESTDIR)$(docdir)/$$f; \
	done
	for f in $(PROCESSEDDOCFILES); do \
	  $(RM) $(DESTDIR)$(docdir)/$$f; \
	  $(INSTALL_DATA) $$f $(DESTDIR)$(docdir)/$$f; \
	done

install_infodoc: install_always groff.info
# Prefer info files in builddir over srcdir; we test for
# the existence of `groff.info'.
	-test -d $(DESTDIR)$(infodir) || $(mkinstalldirs) $(DESTDIR)$(infodir)
	d=.; test -f "groff.info" || d=$(srcdir); \
	  for p in $$d/groff.info `ls $$d/groff.info*`; do \
	    f=`basename $$p`; \
	    $(RM) $(DESTDIR)$(infodir)/$$f; \
	    $(INSTALL_DATA) $$p $(DESTDIR)$(infodir)/$$f; \
	  done
	$(INSTALL_INFO) --info-dir=$(DESTDIR)$(infodir) \
	  $(DESTDIR)$(infodir)/groff.info

install_htmldoc: install_always $(HTMLDOCFILES)
	-test -d $(DESTDIR)$(htmldocdir) \
	  || $(mkinstalldirs) $(DESTDIR)$(htmldocdir)
	for f in `ls $(HTMLDOCFILESALL)`; do \
	  $(RM) $(DESTDIR)$(htmldocdir)/$$f; \
	  $(INSTALL_DATA) $$f $(DESTDIR)$(htmldocdir)/$$f; \
	done
	-test -d $(DESTDIR)$(htmldocimagedir) \
	  || $(mkinstalldirs) $(DESTDIR)$(htmldocimagedir)
	$(RM) $(DESTDIR)$(htmldocimagedir)/$(HTMLDOCIMAGEFILES)
	$(INSTALL_DATA) $(imagedir)/$(HTMLDOCIMAGEFILES) \
	  $(DESTDIR)$(htmldocimagedir)

install_examples: install_always install_examples_always \
		  $(make_install_htmlexamples)

install_examples_always: gnu.eps $(EXAMPLEFILES) $(PROCESSEDEXAMPLEFILES)
# Prefer gnu.eps in builddir over srcdir.
	-test -d $(DESTDIR)$(exampledir) \
	  || $(mkinstalldirs) $(DESTDIR)$(exampledir)
	d=.; test -f "gnu.eps" || d=$(srcdir); \
	  $(RM) $(DESTDIR)$(exampledir)/gnu.eps; \
	  $(INSTALL_DATA) $$d/gnu.eps $(DESTDIR)$(exampledir)/gnu.eps
	for f in $(EXAMPLEFILES); do \
	  $(RM) $(DESTDIR)$(exampledir)/$$f; \
	  $(INSTALL_DATA) $(srcdir)/$$f $(DESTDIR)$(exampledir)/$$f; \
	done
	for f in $(PROCESSEDEXAMPLEFILES); do \
	  $(RM) $(DESTDIR)$(exampledir)/$$f; \
	  $(INSTALL_DATA) $$f $(DESTDIR)$(exampledir)/$$f; \
	done

install_htmlexamples: install_examples_always $(HTMLEXAMPLEFILES)
	for f in `ls $(HTMLEXAMPLEFILESALL)`; do \
	  $(RM) $(DESTDIR)$(exampledir)/$$f; \
	  $(INSTALL_DATA) $$f $(DESTDIR)$(exampledir)/$$f; \
	done
	-test -d $(DESTDIR)$(exampleimagedir) \
	  || $(mkinstalldirs) $(DESTDIR)$(exampleimagedir)
	$(RM) $(DESTDIR)$(exampleimagedir)/$(HTMLEXAMPLEIMAGEFILES)
	$(INSTALL_DATA) $(imagedir)/$(HTMLEXAMPLEIMAGEFILES) \
	  $(DESTDIR)$(exampleimagedir)

uninstall_sub: uninstall_always \
		$(make_uninstall_infodoc) $(make_uninstall_htmldoc) \
		$(make_uninstall_examples)

uninstall_always:
	-for f in $(DOCFILES) $(PROCESSEDDOCFILES); do \
	  $(RM) $(DESTDIR)$(docdir)/$$f; \
	done

uninstall_infodoc: uninstall_always
	-$(INSTALL_INFO) --remove --info-dir=$(DESTDIR)$(infodir) \
	  $(DESTDIR)$(infodir)/groff.info
	-for f in groff `ls groff.info*`; do \
	  $(RM) $(DESTDIR)$(infodir)/$$f; \
	done

uninstall_htmldoc: uninstall_always
	-for f in `ls $(HTMLDOCFILESALL)`; do \
	  $(RM) $(DESTDIR)$(htmldocdir)/$$f; \
	done
	$(RM) $(DESTDIR)$(htmldocimagedir)/$(HTMLDOCIMAGEFILES)
	-test -d $(DESTDIR)$(htmldocimagedir) && \
	  rmdir $(DESTDIR)$(htmldocimagedir)

uninstall_examples: uninstall_always uninstall_examples_always \
		    $(make_uninstall_htmlexamples)
	-test -d $(DESTDIR)$(exampledir) && \
	  rmdir $(DESTDIR)$(exampledir)

uninstall_examples_always:
	-for f in $(EXAMPLEFILES) $(PROCESSEDEXAMPLEFILES); do \
	  $(RM) $(DESTDIR)$(exampledir)/$$f; \
	done
	$(RM) $(DESTDIR)$(exampledir)/gnu.eps

uninstall_htmlexamples: uninstall_examples_always
	-for f in `ls $(HTMLEXAMPLEFILESALL)`; do \
	  $(RM) $(DESTDIR)$(exampledir)/$$f; \
	done
	$(RM) $(DESTDIR)$(exampleimagedir)/$(HTMLEXAMPLEIMAGEFILES)
	-test -d $(DESTDIR)$(exampleimagedir) && \
	  rmdir $(DESTDIR)$(exampleimagedir)

########################################################################
# Emacs settings
########################################################################
#
# Local Variables:
# mode: makefile
# End:
