# Makefile for PO directory in any package using GNU gettext.
# Copyright (C) 1995-1997, 2000-2007, 2009-2010 by Ulrich Drepper <drepper@gnu.ai.mit.edu>
#
# This file can be copied and used freely without restrictions.  It can
# be used in projects which are not available under the GNU General Public
# License but which still want to provide support for the GNU gettext
# functionality.
# Please note that the actual code of GNU gettext is covered by the GNU
# General Public License and is *not* in the public domain.
#
# Origin: gettext-0.18
GETTEXT_MACRO_VERSION = 0.18

PACKAGE = grub
VERSION = 2.00
PACKAGE_BUGREPORT = bug-grub@gnu.org

SHELL = /bin/sh


srcdir = .
top_srcdir = ..


prefix = /usr/local
exec_prefix = ${prefix}
datarootdir = ${prefix}/share
datadir = ${datarootdir}
localedir = ${datarootdir}/locale
gettextsrcdir = $(datadir)/gettext/po

INSTALL = /usr/bin/install -c
INSTALL_DATA = ${INSTALL} -m 644

# We use $(mkdir_p).
# In automake <= 1.9.x, $(mkdir_p) is defined either as "mkdir -p --" or as
# "$(mkinstalldirs)" or as "$(install_sh) -d". For these automake versions,
# ${SHELL} /home/doug/Downloads/grub-2.00/build-aux/install-sh does not start with $(SHELL), so we add it.
# In automake >= 1.10, /bin/mkdir -p is derived from ${MKDIR_P}, which is defined
# either as "/path/to/mkdir -p" or ".../install-sh -c -d". For these automake
# versions, $(mkinstalldirs) and $(install_sh) are unused.
mkinstalldirs = $(SHELL) ${SHELL} /home/doug/Downloads/grub-2.00/build-aux/install-sh -d
install_sh = $(SHELL) ${SHELL} /home/doug/Downloads/grub-2.00/build-aux/install-sh
MKDIR_P = /bin/mkdir -p
mkdir_p = /bin/mkdir -p

GMSGFMT_ = /usr/bin/msgfmt
GMSGFMT_no = /usr/bin/msgfmt
GMSGFMT_yes = /usr/bin/msgfmt
GMSGFMT = $(GMSGFMT_$(USE_MSGCTXT))
MSGFMT_ = /usr/bin/msgfmt
MSGFMT_no = /usr/bin/msgfmt
MSGFMT_yes = /usr/bin/msgfmt
MSGFMT = $(MSGFMT_$(USE_MSGCTXT))
XGETTEXT_ = /usr/bin/xgettext
XGETTEXT_no = /usr/bin/xgettext
XGETTEXT_yes = /usr/bin/xgettext
XGETTEXT = $(XGETTEXT_$(USE_MSGCTXT))
MSGMERGE = msgmerge
MSGMERGE_UPDATE = /usr/bin/msgmerge --update
MSGINIT = msginit
MSGCONV = msgconv
MSGFILTER = msgfilter

POFILES =  ast.po ca.po da.po de.po de_CH.po de@hebrew.po en@arabic.po en@cyrillic.po en@greek.po en@hebrew.po en@piglatin.po en@quot.po eo.po fi.po fr.po hu.po id.po it.po ja.po nl.po pa.po pl.po ru.po sv.po uk.po vi.po zh_CN.po zh_TW.po
GMOFILES =  ast.gmo ca.gmo da.gmo de.gmo de_CH.gmo de@hebrew.gmo en@arabic.gmo en@cyrillic.gmo en@greek.gmo en@hebrew.gmo en@piglatin.gmo en@quot.gmo eo.gmo fi.gmo fr.gmo hu.gmo id.gmo it.gmo ja.gmo nl.gmo pa.gmo pl.gmo ru.gmo sv.gmo uk.gmo vi.gmo zh_CN.gmo zh_TW.gmo
UPDATEPOFILES =  ast.po-update ca.po-update da.po-update de.po-update de_CH.po-update de@hebrew.po-update en@arabic.po-update en@cyrillic.po-update en@greek.po-update en@hebrew.po-update en@piglatin.po-update en@quot.po-update eo.po-update fi.po-update fr.po-update hu.po-update id.po-update it.po-update ja.po-update nl.po-update pa.po-update pl.po-update ru.po-update sv.po-update uk.po-update vi.po-update zh_CN.po-update zh_TW.po-update
DUMMYPOFILES =  ast.nop ca.nop da.nop de.nop de_CH.nop de@hebrew.nop en@arabic.nop en@cyrillic.nop en@greek.nop en@hebrew.nop en@piglatin.nop en@quot.nop eo.nop fi.nop fr.nop hu.nop id.nop it.nop ja.nop nl.nop pa.nop pl.nop ru.nop sv.nop uk.nop vi.nop zh_CN.nop zh_TW.nop
DISTFILES.common = Makefile.in.in remove-potcdate.sin \
$(DISTFILES.common.extra1) $(DISTFILES.common.extra2) \
$(DISTFILES.common.extra3) $(DISTFILES.common.extra4)
DISTFILES = $(DISTFILES.common) Makevars POTFILES.in POTFILES-shell.in \
$(POFILES) $(GMOFILES) \
$(DISTFILES.extra1) $(DISTFILES.extra2) $(DISTFILES.extra3) $(DISTFILES.extra4) grub.d.sed README

POTFILES = \
     .././build-aux/arg-nonnull.h \
     .././build-aux/c++defs.h \
     .././build-aux/warn-on-use.h \
     .././grub-core/boot/decompressor/minilib.c \
     .././grub-core/boot/decompressor/none.c \
     .././grub-core/boot/decompressor/xz.c \
     .././grub-core/bus/bonito.c \
     .././grub-core/bus/cs5536.c \
     .././grub-core/bus/emu/pci.c \
     .././grub-core/bus/pci.c \
     .././grub-core/bus/usb/ehci.c \
     .././grub-core/bus/usb/emu/usb.c \
     .././grub-core/bus/usb/ohci.c \
     .././grub-core/bus/usb/serial/common.c \
     .././grub-core/bus/usb/serial/ftdi.c \
     .././grub-core/bus/usb/serial/pl2303.c \
     .././grub-core/bus/usb/uhci.c \
     .././grub-core/bus/usb/usb.c \
     .././grub-core/bus/usb/usbhub.c \
     .././grub-core/bus/usb/usbtrans.c \
     .././grub-core/commands/acpi.c \
     .././grub-core/commands/acpihalt.c \
     .././grub-core/commands/arc/lsdev.c \
     .././grub-core/commands/blocklist.c \
     .././grub-core/commands/boot.c \
     .././grub-core/commands/cacheinfo.c \
     .././grub-core/commands/cat.c \
     .././grub-core/commands/cmp.c \
     .././grub-core/commands/configfile.c \
     .././grub-core/commands/date.c \
     .././grub-core/commands/echo.c \
     .././grub-core/commands/efi/acpi.c \
     .././grub-core/commands/efi/fixvideo.c \
     .././grub-core/commands/efi/loadbios.c \
     .././grub-core/commands/efi/lsefimmap.c \
     .././grub-core/commands/efi/lsefisystab.c \
     .././grub-core/commands/efi/lssal.c \
     .././grub-core/commands/extcmd.c \
     .././grub-core/commands/gptsync.c \
     .././grub-core/commands/halt.c \
     .././grub-core/commands/hashsum.c \
     .././grub-core/commands/hdparm.c \
     .././grub-core/commands/help.c \
     .././grub-core/commands/hexdump.c \
     .././grub-core/commands/i386/cmostest.c \
     .././grub-core/commands/i386/cpuid.c \
     .././grub-core/commands/i386/pc/acpi.c \
     .././grub-core/commands/i386/pc/drivemap.c \
     .././grub-core/commands/i386/pc/halt.c \
     .././grub-core/commands/i386/pc/lsapm.c \
     .././grub-core/commands/i386/pc/play.c \
     .././grub-core/commands/i386/pc/sendkey.c \
     .././grub-core/commands/ieee1275/suspend.c \
     .././grub-core/commands/iorw.c \
     .././grub-core/commands/keylayouts.c \
     .././grub-core/commands/keystatus.c \
     .././grub-core/commands/legacycfg.c \
     .././grub-core/commands/loadenv.c \
     .././grub-core/commands/lsacpi.c \
     .././grub-core/commands/ls.c \
     .././grub-core/commands/lsmmap.c \
     .././grub-core/commands/lspci.c \
     .././grub-core/commands/memrw.c \
     .././grub-core/commands/menuentry.c \
     .././grub-core/commands/minicmd.c \
     .././grub-core/commands/mips/loongson/lsspd.c \
     .././grub-core/commands/parttool.c \
     .././grub-core/commands/password.c \
     .././grub-core/commands/password_pbkdf2.c \
     .././grub-core/commands/probe.c \
     .././grub-core/commands/read.c \
     .././grub-core/commands/reboot.c \
     .././grub-core/commands/regexp.c \
     .././grub-core/commands/search.c \
     .././grub-core/commands/search_file.c \
     .././grub-core/commands/search_label.c \
     .././grub-core/commands/search_uuid.c \
     .././grub-core/commands/search_wrap.c \
     .././grub-core/commands/setpci.c \
     .././grub-core/commands/sleep.c \
     .././grub-core/commands/terminal.c \
     .././grub-core/commands/test.c \
     .././grub-core/commands/testload.c \
     .././grub-core/commands/time.c \
     .././grub-core/commands/true.c \
     .././grub-core/commands/usbtest.c \
     .././grub-core/commands/videoinfo.c \
     .././grub-core/commands/videotest.c \
     .././grub-core/commands/wildcard.c \
     .././grub-core/commands/xnu_uuid.c \
     .././grub-core/disk/AFSplitter.c \
     .././grub-core/disk/ahci.c \
     .././grub-core/disk/arc/arcdisk.c \
     .././grub-core/disk/ata.c \
     .././grub-core/disk/cryptodisk.c \
     .././grub-core/disk/diskfilter.c \
     .././grub-core/disk/dmraid_nvidia.c \
     .././grub-core/disk/efi/efidisk.c \
     .././grub-core/disk/geli.c \
     .././grub-core/disk/host.c \
     .././grub-core/disk/i386/pc/biosdisk.c \
     .././grub-core/disk/ieee1275/nand.c \
     .././grub-core/disk/ieee1275/ofdisk.c \
     .././grub-core/disk/ldm.c \
     .././grub-core/disk/loopback.c \
     .././grub-core/disk/luks.c \
     .././grub-core/disk/lvm.c \
     .././grub-core/disk/mdraid1x_linux.c \
     .././grub-core/disk/mdraid_linux_be.c \
     .././grub-core/disk/mdraid_linux.c \
     .././grub-core/disk/memdisk.c \
     .././grub-core/disk/pata.c \
     .././grub-core/disk/raid5_recover.c \
     .././grub-core/disk/raid6_recover.c \
     .././grub-core/disk/scsi.c \
     .././grub-core/disk/usbms.c \
     .././grub-core/efiemu/i386/coredetect.c \
     .././grub-core/efiemu/i386/loadcore32.c \
     .././grub-core/efiemu/i386/loadcore64.c \
     .././grub-core/efiemu/i386/nocfgtables.c \
     .././grub-core/efiemu/i386/pc/cfgtables.c \
     .././grub-core/efiemu/loadcore32.c \
     .././grub-core/efiemu/loadcore64.c \
     .././grub-core/efiemu/loadcore.c \
     .././grub-core/efiemu/loadcore_common.c \
     .././grub-core/efiemu/main.c \
     .././grub-core/efiemu/mm.c \
     .././grub-core/efiemu/pnvram.c \
     .././grub-core/efiemu/prepare32.c \
     .././grub-core/efiemu/prepare64.c \
     .././grub-core/efiemu/prepare.c \
     .././grub-core/efiemu/runtime/config.h \
     .././grub-core/efiemu/runtime/efiemu.c \
     .././grub-core/efiemu/symbols.c \
     .././grub-core/font/font.c \
     .././grub-core/font/font_cmd.c \
     .././grub-core/fs/affs.c \
     .././grub-core/fs/afs.c \
     .././grub-core/fs/bfs.c \
     .././grub-core/fs/btrfs.c \
     .././grub-core/fs/cpio_be.c \
     .././grub-core/fs/cpio.c \
     .././grub-core/fs/exfat.c \
     .././grub-core/fs/ext2.c \
     .././grub-core/fs/fat.c \
     .././grub-core/fs/fshelp.c \
     .././grub-core/fs/hfs.c \
     .././grub-core/fs/hfsplus.c \
     .././grub-core/fs/iso9660.c \
     .././grub-core/fs/jfs.c \
     .././grub-core/fs/minix2_be.c \
     .././grub-core/fs/minix2.c \
     .././grub-core/fs/minix3_be.c \
     .././grub-core/fs/minix3.c \
     .././grub-core/fs/minix_be.c \
     .././grub-core/fs/minix.c \
     .././grub-core/fs/newc.c \
     .././grub-core/fs/nilfs2.c \
     .././grub-core/fs/ntfs.c \
     .././grub-core/fs/ntfscomp.c \
     .././grub-core/fs/odc.c \
     .././grub-core/fs/reiserfs.c \
     .././grub-core/fs/romfs.c \
     .././grub-core/fs/sfs.c \
     .././grub-core/fs/squash4.c \
     .././grub-core/fs/tar.c \
     .././grub-core/fs/udf.c \
     .././grub-core/fs/ufs2.c \
     .././grub-core/fs/ufs.c \
     .././grub-core/fs/xfs.c \
     .././grub-core/fs/zfs/zfs.c \
     .././grub-core/fs/zfs/zfscrypt.c \
     .././grub-core/fs/zfs/zfs_fletcher.c \
     .././grub-core/fs/zfs/zfsinfo.c \
     .././grub-core/fs/zfs/zfs_lzjb.c \
     .././grub-core/fs/zfs/zfs_sha256.c \
     .././grub-core/gdb/cstub.c \
     .././grub-core/gdb/gdb.c \
     .././grub-core/gdb/i386/idt.c \
     .././grub-core/gdb/i386/signal.c \
     .././grub-core/gentrigtables.c \
     .././grub-core/gettext/gettext.c \
     .././grub-core/gfxmenu/font.c \
     .././grub-core/gfxmenu/gfxmenu.c \
     .././grub-core/gfxmenu/gui_box.c \
     .././grub-core/gfxmenu/gui_canvas.c \
     .././grub-core/gfxmenu/gui_circular_progress.c \
     .././grub-core/gfxmenu/gui_image.c \
     .././grub-core/gfxmenu/gui_label.c \
     .././grub-core/gfxmenu/gui_list.c \
     .././grub-core/gfxmenu/gui_progress_bar.c \
     .././grub-core/gfxmenu/gui_string_util.c \
     .././grub-core/gfxmenu/gui_util.c \
     .././grub-core/gfxmenu/icon_manager.c \
     .././grub-core/gfxmenu/model.c \
     .././grub-core/gfxmenu/theme_loader.c \
     .././grub-core/gfxmenu/view.c \
     .././grub-core/gfxmenu/widget-box.c \
     .././grub-core/gnulib/alloca.c \
     .././grub-core/gnulib/alloca.in.h \
     .././grub-core/gnulib/argp-ba.c \
     .././grub-core/gnulib/argp-eexst.c \
     .././grub-core/gnulib/argp-fmtstream.c \
     .././grub-core/gnulib/argp-fmtstream.h \
     .././grub-core/gnulib/argp-fs-xinl.c \
     .././grub-core/gnulib/argp.h \
     .././grub-core/gnulib/argp-help.c \
     .././grub-core/gnulib/argp-namefrob.h \
     .././grub-core/gnulib/argp-parse.c \
     .././grub-core/gnulib/argp-pin.c \
     .././grub-core/gnulib/argp-pv.c \
     .././grub-core/gnulib/argp-pvh.c \
     .././grub-core/gnulib/argp-xinl.c \
     .././grub-core/gnulib/asnprintf.c \
     .././grub-core/gnulib/basename-lgpl.c \
     .././grub-core/gnulib/btowc.c \
     .././grub-core/gnulib/dirname.h \
     .././grub-core/gnulib/dirname-lgpl.c \
     .././grub-core/gnulib/errno.in.h \
     .././grub-core/gnulib/error.c \
     .././grub-core/gnulib/error.h \
     .././grub-core/gnulib/float+.h \
     .././grub-core/gnulib/float.in.h \
     .././grub-core/gnulib/fnmatch.c \
     .././grub-core/gnulib/fnmatch.in.h \
     .././grub-core/gnulib/fnmatch_loop.c \
     .././grub-core/gnulib/getdelim.c \
     .././grub-core/gnulib/getline.c \
     .././grub-core/gnulib/getopt1.c \
     .././grub-core/gnulib/getopt.c \
     .././grub-core/gnulib/getopt.in.h \
     .././grub-core/gnulib/getopt_int.h \
     .././grub-core/gnulib/gettext.h \
     .././grub-core/gnulib/intprops.h \
     .././grub-core/gnulib/langinfo.in.h \
     .././grub-core/gnulib/localcharset.c \
     .././grub-core/gnulib/localcharset.h \
     .././grub-core/gnulib/malloc.c \
     .././grub-core/gnulib/mbrtowc.c \
     .././grub-core/gnulib/mbsinit.c \
     .././grub-core/gnulib/mbsrtowcs.c \
     .././grub-core/gnulib/mbsrtowcs-state.c \
     .././grub-core/gnulib/memchr.c \
     .././grub-core/gnulib/mempcpy.c \
     .././grub-core/gnulib/nl_langinfo.c \
     .././grub-core/gnulib/printf-args.c \
     .././grub-core/gnulib/printf-args.h \
     .././grub-core/gnulib/printf-parse.c \
     .././grub-core/gnulib/printf-parse.h \
     .././grub-core/gnulib/progname.c \
     .././grub-core/gnulib/progname.h \
     .././grub-core/gnulib/rawmemchr.c \
     .././grub-core/gnulib/realloc.c \
     .././grub-core/gnulib/regcomp.c \
     .././grub-core/gnulib/regex.c \
     .././grub-core/gnulib/regexec.c \
     .././grub-core/gnulib/regex.h \
     .././grub-core/gnulib/regex_internal.c \
     .././grub-core/gnulib/regex_internal.h \
     .././grub-core/gnulib/size_max.h \
     .././grub-core/gnulib/sleep.c \
     .././grub-core/gnulib/stdbool.in.h \
     .././grub-core/gnulib/stddef.in.h \
     .././grub-core/gnulib/stdint.in.h \
     .././grub-core/gnulib/stdio.in.h \
     .././grub-core/gnulib/stdio-write.c \
     .././grub-core/gnulib/stdlib.in.h \
     .././grub-core/gnulib/strcasecmp.c \
     .././grub-core/gnulib/strchrnul.c \
     .././grub-core/gnulib/streq.h \
     .././grub-core/gnulib/strerror.c \
     .././grub-core/gnulib/string.in.h \
     .././grub-core/gnulib/strings.in.h \
     .././grub-core/gnulib/stripslash.c \
     .././grub-core/gnulib/strncasecmp.c \
     .././grub-core/gnulib/strndup.c \
     .././grub-core/gnulib/strnlen1.c \
     .././grub-core/gnulib/strnlen1.h \
     .././grub-core/gnulib/strnlen.c \
     .././grub-core/gnulib/sysexits.in.h \
     .././grub-core/gnulib/sys_wait.in.h \
     .././grub-core/gnulib/unistd.in.h \
     .././grub-core/gnulib/vasnprintf.c \
     .././grub-core/gnulib/vasnprintf.h \
     .././grub-core/gnulib/verify.h \
     .././grub-core/gnulib/vsnprintf.c \
     .././grub-core/gnulib/wchar.in.h \
     .././grub-core/gnulib/wcrtomb.c \
     .././grub-core/gnulib/wctype.in.h \
     .././grub-core/gnulib/xsize.h \
     .././grub-core/hello/hello.c \
     .././grub-core/hook/datehook.c \
     .././grub-core/io/bufio.c \
     .././grub-core/io/gzio.c \
     .././grub-core/io/lzopio.c \
     .././grub-core/io/xzio.c \
     .././grub-core/kern/command.c \
     .././grub-core/kern/corecmd.c \
     .././grub-core/kern/device.c \
     .././grub-core/kern/disk.c \
     .././grub-core/kern/dl.c \
     .././grub-core/kern/efi/efi.c \
     .././grub-core/kern/efi/init.c \
     .././grub-core/kern/efi/mm.c \
     .././grub-core/kern/elf.c \
     .././grub-core/kern/emu/argp_common.c \
     .././grub-core/kern/emu/cache.c \
     .././grub-core/kern/emu/full.c \
     .././grub-core/kern/emu/hostdisk.c \
     .././grub-core/kern/emu/hostfs.c \
     .././grub-core/kern/emu/lite.c \
     .././grub-core/kern/emu/main.c \
     .././grub-core/kern/emu/misc.c \
     .././grub-core/kern/emu/mm.c \
     .././grub-core/kern/emu/time.c \
     .././grub-core/kern/env.c \
     .././grub-core/kern/err.c \
     .././grub-core/kern/file.c \
     .././grub-core/kern/fs.c \
     .././grub-core/kern/generic/millisleep.c \
     .././grub-core/kern/generic/rtc_get_time_ms.c \
     .././grub-core/kern/i386/coreboot/init.c \
     .././grub-core/kern/i386/coreboot/mmap.c \
     .././grub-core/kern/i386/dl.c \
     .././grub-core/kern/i386/efi/init.c \
     .././grub-core/kern/i386/multiboot_mmap.c \
     .././grub-core/kern/i386/pc/init.c \
     .././grub-core/kern/i386/pc/mmap.c \
     .././grub-core/kern/i386/pit.c \
     .././grub-core/kern/i386/qemu/mmap.c \
     .././grub-core/kern/i386/tsc.c \
     .././grub-core/kern/ia64/dl.c \
     .././grub-core/kern/ia64/dl_helper.c \
     .././grub-core/kern/ia64/efi/init.c \
     .././grub-core/kern/ieee1275/cmain.c \
     .././grub-core/kern/ieee1275/ieee1275.c \
     .././grub-core/kern/ieee1275/init.c \
     .././grub-core/kern/ieee1275/mmap.c \
     .././grub-core/kern/ieee1275/openfw.c \
     .././grub-core/kern/list.c \
     .././grub-core/kern/main.c \
     .././grub-core/kern/mips/arc/init.c \
     .././grub-core/kern/mips/dl.c \
     .././grub-core/kern/mips/init.c \
     .././grub-core/kern/mips/loongson/init.c \
     .././grub-core/kern/mips/qemu_mips/init.c \
     .././grub-core/kern/misc.c \
     .././grub-core/kern/mm.c \
     .././grub-core/kern/parser.c \
     .././grub-core/kern/partition.c \
     .././grub-core/kern/powerpc/dl.c \
     .././grub-core/kern/rescue_parser.c \
     .././grub-core/kern/rescue_reader.c \
     .././grub-core/kern/sparc64/dl.c \
     .././grub-core/kern/sparc64/ieee1275/ieee1275.c \
     .././grub-core/kern/term.c \
     .././grub-core/kern/time.c \
     .././grub-core/kern/vga_init.c \
     .././grub-core/kern/x86_64/dl.c \
     .././grub-core/lib/adler32.c \
     .././grub-core/lib/arc/datetime.c \
     .././grub-core/lib/arg.c \
     .././grub-core/lib/backtrace.c \
     .././grub-core/lib/cmdline.c \
     .././grub-core/lib/cmos_datetime.c \
     .././grub-core/lib/crc64.c \
     .././grub-core/lib/crc.c \
     .././grub-core/lib/crypto.c \
     .././grub-core/lib/efi/datetime.c \
     .././grub-core/lib/efi/halt.c \
     .././grub-core/lib/efi/reboot.c \
     .././grub-core/lib/efi/relocator.c \
     .././grub-core/lib/emu/halt.c \
     .././grub-core/lib/envblk.c \
     .././grub-core/lib/fake_module.c \
     .././grub-core/lib/hexdump.c \
     .././grub-core/lib/i386/backtrace.c \
     .././grub-core/lib/i386/halt.c \
     .././grub-core/lib/i386/pc/biosnum.c \
     .././grub-core/lib/i386/pc/vesa_modes_table.c \
     .././grub-core/lib/i386/reboot.c \
     .././grub-core/lib/i386/relocator.c \
     .././grub-core/lib/ieee1275/cmos.c \
     .././grub-core/lib/ieee1275/datetime.c \
     .././grub-core/lib/ieee1275/halt.c \
     .././grub-core/lib/ieee1275/reboot.c \
     .././grub-core/lib/ieee1275/relocator.c \
     .././grub-core/lib/legacy_parse.c \
     .././grub-core/lib/libgcrypt/cipher/ac.c \
     .././grub-core/lib/libgcrypt/cipher/arcfour.c \
     .././grub-core/lib/libgcrypt/cipher/bithelp.h \
     .././grub-core/lib/libgcrypt/cipher/blowfish.c \
     .././grub-core/lib/libgcrypt/cipher/camellia.c \
     .././grub-core/lib/libgcrypt/cipher/camellia-glue.c \
     .././grub-core/lib/libgcrypt/cipher/camellia.h \
     .././grub-core/lib/libgcrypt/cipher/cast5.c \
     .././grub-core/lib/libgcrypt/cipher/cipher.c \
     .././grub-core/lib/libgcrypt/cipher/crc.c \
     .././grub-core/lib/libgcrypt/cipher/des.c \
     .././grub-core/lib/libgcrypt/cipher/dsa.c \
     .././grub-core/lib/libgcrypt/cipher/ecc.c \
     .././grub-core/lib/libgcrypt/cipher/elgamal.c \
     .././grub-core/lib/libgcrypt/cipher/hash-common.c \
     .././grub-core/lib/libgcrypt/cipher/hash-common.h \
     .././grub-core/lib/libgcrypt/cipher/hmac-tests.c \
     .././grub-core/lib/libgcrypt/cipher/md4.c \
     .././grub-core/lib/libgcrypt/cipher/md5.c \
     .././grub-core/lib/libgcrypt/cipher/md.c \
     .././grub-core/lib/libgcrypt/cipher/primegen.c \
     .././grub-core/lib/libgcrypt/cipher/pubkey.c \
     .././grub-core/lib/libgcrypt/cipher/rfc2268.c \
     .././grub-core/lib/libgcrypt/cipher/rijndael.c \
     .././grub-core/lib/libgcrypt/cipher/rijndael-tables.h \
     .././grub-core/lib/libgcrypt/cipher/rmd160.c \
     .././grub-core/lib/libgcrypt/cipher/rmd.h \
     .././grub-core/lib/libgcrypt/cipher/rsa.c \
     .././grub-core/lib/libgcrypt/cipher/seed.c \
     .././grub-core/lib/libgcrypt/cipher/serpent.c \
     .././grub-core/lib/libgcrypt/cipher/sha1.c \
     .././grub-core/lib/libgcrypt/cipher/sha256.c \
     .././grub-core/lib/libgcrypt/cipher/sha512.c \
     .././grub-core/lib/libgcrypt/cipher/tiger.c \
     .././grub-core/lib/libgcrypt/cipher/twofish.c \
     .././grub-core/lib/libgcrypt/cipher/whirlpool.c \
     .././grub-core/lib/libgcrypt_wrap/cipher_wrap.h \
     .././grub-core/lib/LzFind.c \
     .././grub-core/lib/LzmaDec.c \
     .././grub-core/lib/LzmaEnc.c \
     .././grub-core/lib/minilzo/lzoconf.h \
     .././grub-core/lib/minilzo/lzodefs.h \
     .././grub-core/lib/minilzo/minilzo.c \
     .././grub-core/lib/minilzo/minilzo.h \
     .././grub-core/lib/mips/arc/reboot.c \
     .././grub-core/lib/mips/loongson/reboot.c \
     .././grub-core/lib/mips/qemu_mips/reboot.c \
     .././grub-core/lib/mips/relocator.c \
     .././grub-core/lib/pbkdf2.c \
     .././grub-core/lib/posix_wrap/assert.h \
     .././grub-core/lib/posix_wrap/ctype.h \
     .././grub-core/lib/posix_wrap/errno.h \
     .././grub-core/lib/posix_wrap/inttypes.h \
     .././grub-core/lib/posix_wrap/langinfo.h \
     .././grub-core/lib/posix_wrap/limits.h \
     .././grub-core/lib/posix_wrap/localcharset.h \
     .././grub-core/lib/posix_wrap/locale.h \
     .././grub-core/lib/posix_wrap/stdint.h \
     .././grub-core/lib/posix_wrap/stdio.h \
     .././grub-core/lib/posix_wrap/stdlib.h \
     .././grub-core/lib/posix_wrap/string.h \
     .././grub-core/lib/posix_wrap/sys/types.h \
     .././grub-core/lib/posix_wrap/unistd.h \
     .././grub-core/lib/posix_wrap/wchar.h \
     .././grub-core/lib/posix_wrap/wctype.h \
     .././grub-core/lib/powerpc/relocator.c \
     .././grub-core/lib/priority_queue.c \
     .././grub-core/lib/reed_solomon.c \
     .././grub-core/lib/relocator.c \
     .././grub-core/lib/xzembed/xz_config.h \
     .././grub-core/lib/xzembed/xz_dec_bcj.c \
     .././grub-core/lib/xzembed/xz_dec_lzma2.c \
     .././grub-core/lib/xzembed/xz_dec_stream.c \
     .././grub-core/lib/xzembed/xz.h \
     .././grub-core/lib/xzembed/xz_lzma2.h \
     .././grub-core/lib/xzembed/xz_private.h \
     .././grub-core/lib/xzembed/xz_stream.h \
     .././grub-core/loader/aout.c \
     .././grub-core/loader/efi/appleloader.c \
     .././grub-core/loader/efi/chainloader.c \
     .././grub-core/loader/i386/bsd32.c \
     .././grub-core/loader/i386/bsd64.c \
     .././grub-core/loader/i386/bsd.c \
     .././grub-core/loader/i386/bsd_pagetable.c \
     .././grub-core/loader/i386/bsdXX.c \
     .././grub-core/loader/i386/coreboot/chainloader.c \
     .././grub-core/loader/i386/linux.c \
     .././grub-core/loader/i386/multiboot_mbi.c \
     .././grub-core/loader/i386/pc/chainloader.c \
     .././grub-core/loader/i386/pc/freedos.c \
     .././grub-core/loader/i386/pc/linux.c \
     .././grub-core/loader/i386/pc/ntldr.c \
     .././grub-core/loader/i386/pc/plan9.c \
     .././grub-core/loader/i386/pc/pxechainloader.c \
     .././grub-core/loader/i386/xnu.c \
     .././grub-core/loader/ia64/efi/linux.c \
     .././grub-core/loader/lzss.c \
     .././grub-core/loader/macho32.c \
     .././grub-core/loader/macho64.c \
     .././grub-core/loader/macho.c \
     .././grub-core/loader/machoXX.c \
     .././grub-core/loader/mips/linux.c \
     .././grub-core/loader/multiboot.c \
     .././grub-core/loader/multiboot_elfxx.c \
     .././grub-core/loader/multiboot_mbi2.c \
     .././grub-core/loader/powerpc/ieee1275/linux.c \
     .././grub-core/loader/sparc64/ieee1275/linux.c \
     .././grub-core/loader/xnu.c \
     .././grub-core/loader/xnu_resume.c \
     .././grub-core/mmap/efi/mmap.c \
     .././grub-core/mmap/i386/mmap.c \
     .././grub-core/mmap/i386/pc/mmap.c \
     .././grub-core/mmap/i386/uppermem.c \
     .././grub-core/mmap/mips/uppermem.c \
     .././grub-core/mmap/mmap.c \
     .././grub-core/net/arp.c \
     .././grub-core/net/bootp.c \
     .././grub-core/net/dns.c \
     .././grub-core/net/drivers/efi/efinet.c \
     .././grub-core/net/drivers/emu/emunet.c \
     .././grub-core/net/drivers/i386/pc/pxe.c \
     .././grub-core/net/drivers/ieee1275/ofnet.c \
     .././grub-core/net/ethernet.c \
     .././grub-core/net/http.c \
     .././grub-core/net/icmp6.c \
     .././grub-core/net/icmp.c \
     .././grub-core/net/ip.c \
     .././grub-core/net/netbuff.c \
     .././grub-core/net/net.c \
     .././grub-core/net/tcp.c \
     .././grub-core/net/tftp.c \
     .././grub-core/net/udp.c \
     .././grub-core/normal/auth.c \
     .././grub-core/normal/autofs.c \
     .././grub-core/normal/charset.c \
     .././grub-core/normal/cmdline.c \
     .././grub-core/normal/color.c \
     .././grub-core/normal/completion.c \
     .././grub-core/normal/context.c \
     .././grub-core/normal/crypto.c \
     .././grub-core/normal/datetime.c \
     .././grub-core/normal/dyncmd.c \
     .././grub-core/normal/main.c \
     .././grub-core/normal/menu.c \
     .././grub-core/normal/menu_entry.c \
     .././grub-core/normal/menu_text.c \
     .././grub-core/normal/misc.c \
     .././grub-core/normal/term.c \
     .././grub-core/partmap/acorn.c \
     .././grub-core/partmap/amiga.c \
     .././grub-core/partmap/apple.c \
     .././grub-core/partmap/bsdlabel.c \
     .././grub-core/partmap/dvh.c \
     .././grub-core/partmap/gpt.c \
     .././grub-core/partmap/msdos.c \
     .././grub-core/partmap/plan.c \
     .././grub-core/partmap/sun.c \
     .././grub-core/partmap/sunpc.c \
     .././grub-core/parttool/msdospart.c \
     .././grub-core/script/argv.c \
     .././grub-core/script/execute.c \
     .././grub-core/script/function.c \
     .././grub-core/script/lexer.c \
     .././grub-core/script/main.c \
     .././grub-core/script/script.c \
     .././grub-core/term/arc/console.c \
     .././grub-core/term/at_keyboard.c \
     .././grub-core/term/efi/console.c \
     .././grub-core/term/efi/serial.c \
     .././grub-core/term/emu/console.c \
     .././grub-core/term/gfxterm.c \
     .././grub-core/term/i386/pc/console.c \
     .././grub-core/term/i386/pc/vga_text.c \
     .././grub-core/term/i386/vga_common.c \
     .././grub-core/term/ieee1275/console.c \
     .././grub-core/term/ieee1275/escc.c \
     .././grub-core/term/ieee1275/serial.c \
     .././grub-core/term/ns8250.c \
     .././grub-core/term/serial.c \
     .././grub-core/term/terminfo.c \
     .././grub-core/term/tparm.c \
     .././grub-core/term/usb_keyboard.c \
     .././grub-core/tests/example_functional_test.c \
     .././grub-core/tests/lib/functional_test.c \
     .././grub-core/tests/lib/test.c \
     .././grub-core/tests/test_blockarg.c \
     .././grub-core/video/bitmap.c \
     .././grub-core/video/bitmap_scale.c \
     .././grub-core/video/bochs.c \
     .././grub-core/video/cirrus.c \
     .././grub-core/video/colors.c \
     .././grub-core/video/efi_gop.c \
     .././grub-core/video/efi_uga.c \
     .././grub-core/video/emu/sdl.c \
     .././grub-core/video/fb/fbblit.c \
     .././grub-core/video/fb/fbfill.c \
     .././grub-core/video/fb/fbutil.c \
     .././grub-core/video/fb/video_fb.c \
     .././grub-core/video/i386/pc/vbe.c \
     .././grub-core/video/i386/pc/vga.c \
     .././grub-core/video/ieee1275.c \
     .././grub-core/video/radeon_fuloong2e.c \
     .././grub-core/video/readers/jpeg.c \
     .././grub-core/video/readers/png.c \
     .././grub-core/video/readers/tga.c \
     .././grub-core/video/sis315_init.c \
     .././grub-core/video/sis315pro.c \
     .././grub-core/video/sm712.c \
     .././grub-core/video/sm712_init.c \
     .././grub-core/video/video.c \
     .././include/grub/acorn_filecore.h \
     .././include/grub/acpi.h \
     .././include/grub/aout.h \
     .././include/grub/arc/arc.h \
     .././include/grub/arc/console.h \
     .././include/grub/ata.h \
     .././include/grub/at_keyboard.h \
     .././include/grub/auth.h \
     .././include/grub/autoefi.h \
     .././include/grub/backtrace.h \
     .././include/grub/bitmap.h \
     .././include/grub/bitmap_scale.h \
     .././include/grub/bsdlabel.h \
     .././include/grub/bufio.h \
     .././include/grub/cache.h \
     .././include/grub/charset.h \
     .././include/grub/cmos.h \
     .././include/grub/command.h \
     .././include/grub/cryptodisk.h \
     .././include/grub/crypto.h \
     .././include/grub/cs5536.h \
     .././include/grub/datetime.h \
     .././include/grub/decompressor.h \
     .././include/grub/deflate.h \
     .././include/grub/device.h \
     .././include/grub/diskfilter.h \
     .././include/grub/disk.h \
     .././include/grub/dl.h \
     .././include/grub/efi/api.h \
     .././include/grub/efi/console_control.h \
     .././include/grub/efi/console.h \
     .././include/grub/efi/disk.h \
     .././include/grub/efi/edid.h \
     .././include/grub/efi/efi.h \
     .././include/grub/efiemu/efiemu.h \
     .././include/grub/efiemu/runtime.h \
     .././include/grub/efi/graphics_output.h \
     .././include/grub/efi/memory.h \
     .././include/grub/efi/pci.h \
     .././include/grub/efi/pe32.h \
     .././include/grub/efi/uga_draw.h \
     .././include/grub/elf.h \
     .././include/grub/elfload.h \
     .././include/grub/emu/console.h \
     .././include/grub/emu/export.h \
     .././include/grub/emu/getroot.h \
     .././include/grub/emu/hostdisk.h \
     .././include/grub/emu/misc.h \
     .././include/grub/env.h \
     .././include/grub/env_private.h \
     .././include/grub/err.h \
     .././include/grub/extcmd.h \
     .././include/grub/fat.h \
     .././include/grub/fbblit.h \
     .././include/grub/fbfill.h \
     .././include/grub/fbutil.h \
     .././include/grub/file.h \
     .././include/grub/fontformat.h \
     .././include/grub/font.h \
     .././include/grub/fs.h \
     .././include/grub/fshelp.h \
     .././include/grub/gdb.h \
     .././include/grub/gfxmenu_model.h \
     .././include/grub/gfxmenu_view.h \
     .././include/grub/gfxterm.h \
     .././include/grub/gfxwidgets.h \
     .././include/grub/gpt_partition.h \
     .././include/grub/gui.h \
     .././include/grub/gui_string_util.h \
     .././include/grub/hfs.h \
     .././include/grub/i18n.h \
     .././include/grub/i386/at_keyboard.h \
     .././include/grub/i386/bsd.h \
     .././include/grub/i386/cmos.h \
     .././include/grub/i386/coreboot/boot.h \
     .././include/grub/i386/coreboot/console.h \
     .././include/grub/i386/coreboot/lbio.h \
     .././include/grub/i386/coreboot/memory.h \
     .././include/grub/i386/coreboot/serial.h \
     .././include/grub/i386/coreboot/time.h \
     .././include/grub/i386/cpuid.h \
     .././include/grub/i386/efiemu.h \
     .././include/grub/i386/efi/memory.h \
     .././include/grub/i386/efi/serial.h \
     .././include/grub/i386/floppy.h \
     .././include/grub/i386/freebsd_linker.h \
     .././include/grub/i386/freebsd_reboot.h \
     .././include/grub/i386/gdb.h \
     .././include/grub/i386/ieee1275/ieee1275.h \
     .././include/grub/i386/ieee1275/memory.h \
     .././include/grub/i386/ieee1275/serial.h \
     .././include/grub/i386/io.h \
     .././include/grub/i386/linux.h \
     .././include/grub/i386/macho.h \
     .././include/grub/i386/memory.h \
     .././include/grub/i386/multiboot/boot.h \
     .././include/grub/i386/multiboot/console.h \
     .././include/grub/i386/multiboot.h \
     .././include/grub/i386/multiboot/kernel.h \
     .././include/grub/i386/multiboot/memory.h \
     .././include/grub/i386/multiboot/serial.h \
     .././include/grub/i386/multiboot/time.h \
     .././include/grub/i386/netbsd_bootinfo.h \
     .././include/grub/i386/netbsd_reboot.h \
     .././include/grub/i386/openbsd_bootarg.h \
     .././include/grub/i386/openbsd_reboot.h \
     .././include/grub/i386/pc/apm.h \
     .././include/grub/i386/pc/biosdisk.h \
     .././include/grub/i386/pc/biosnum.h \
     .././include/grub/i386/pc/boot.h \
     .././include/grub/i386/pc/chainloader.h \
     .././include/grub/i386/pc/console.h \
     .././include/grub/i386/pci.h \
     .././include/grub/i386/pc/int.h \
     .././include/grub/i386/pc/kernel.h \
     .././include/grub/i386/pc/memory.h \
     .././include/grub/i386/pc/pxe.h \
     .././include/grub/i386/pc/time.h \
     .././include/grub/i386/pc/vbe.h \
     .././include/grub/i386/pc/vesa_modes_table.h \
     .././include/grub/i386/pit.h \
     .././include/grub/i386/qemu/boot.h \
     .././include/grub/i386/qemu/console.h \
     .././include/grub/i386/qemu/kernel.h \
     .././include/grub/i386/qemu/memory.h \
     .././include/grub/i386/qemu/serial.h \
     .././include/grub/i386/qemu/time.h \
     .././include/grub/i386/reboot.h \
     .././include/grub/i386/relocator.h \
     .././include/grub/i386/relocator_private.h \
     .././include/grub/i386/setjmp.h \
     .././include/grub/i386/time.h \
     .././include/grub/i386/tsc.h \
     .././include/grub/i386/types.h \
     .././include/grub/i386/vga_common.h \
     .././include/grub/i386/xnu.h \
     .././include/grub/ia64/efi/memory.h \
     .././include/grub/ia64/efi/time.h \
     .././include/grub/ia64/kernel.h \
     .././include/grub/ia64/setjmp.h \
     .././include/grub/ia64/time.h \
     .././include/grub/ia64/types.h \
     .././include/grub/icon_manager.h \
     .././include/grub/ieee1275/console.h \
     .././include/grub/ieee1275/ieee1275.h \
     .././include/grub/ieee1275/ofdisk.h \
     .././include/grub/kernel.h \
     .././include/grub/keyboard_layouts.h \
     .././include/grub/legacy_parse.h \
     .././include/grub/lib/arg.h \
     .././include/grub/lib/cmdline.h \
     .././include/grub/lib/crc.h \
     .././include/grub/lib/envblk.h \
     .././include/grub/libgcc.h \
     .././include/grub/lib/hexdump.h \
     .././include/grub/lib/LzFind.h \
     .././include/grub/lib/LzHash.h \
     .././include/grub/lib/LzmaDec.h \
     .././include/grub/lib/LzmaEnc.h \
     .././include/grub/lib/LzmaTypes.h \
     .././include/grub/libpciaccess.h \
     .././include/grub/libusb.h \
     .././include/grub/list.h \
     .././include/grub/loader.h \
     .././include/grub/lvm.h \
     .././include/grub/macho.h \
     .././include/grub/machoload.h \
     .././include/grub/memory.h \
     .././include/grub/menu.h \
     .././include/grub/menu_viewer.h \
     .././include/grub/mips/arc/kernel.h \
     .././include/grub/mips/arc/memory.h \
     .././include/grub/mips/arc/time.h \
     .././include/grub/mips/at_keyboard.h \
     .././include/grub/mips/cache.h \
     .././include/grub/mips/cmos.h \
     .././include/grub/mips/io.h \
     .././include/grub/mips/kernel.h \
     .././include/grub/mips/loongson/at_keyboard.h \
     .././include/grub/mips/loongson/cmos.h \
     .././include/grub/mips/loongson/ec.h \
     .././include/grub/mips/loongson.h \
     .././include/grub/mips/loongson/kernel.h \
     .././include/grub/mips/loongson/memory.h \
     .././include/grub/mips/loongson/pci.h \
     .././include/grub/mips/loongson/serial.h \
     .././include/grub/mips/loongson/time.h \
     .././include/grub/mips/memory.h \
     .././include/grub/mips/mips.h \
     .././include/grub/mips/multiboot.h \
     .././include/grub/mips/pci.h \
     .././include/grub/mips/qemu_mips/at_keyboard.h \
     .././include/grub/mips/qemu_mips/cmos.h \
     .././include/grub/mips/qemu_mips/console.h \
     .././include/grub/mips/qemu_mips/kernel.h \
     .././include/grub/mips/qemu_mips/loader.h \
     .././include/grub/mips/qemu_mips/memory.h \
     .././include/grub/mips/qemu_mips/serial.h \
     .././include/grub/mips/qemu_mips/time.h \
     .././include/grub/mips/relocator.h \
     .././include/grub/mips/setjmp.h \
     .././include/grub/mips/time.h \
     .././include/grub/mips/types.h \
     .././include/grub/misc.h \
     .././include/grub/mm.h \
     .././include/grub/mm_private.h \
     .././include/grub/msdos_partition.h \
     .././include/grub/multiboot.h \
     .././include/grub/multiboot_loader.h \
     .././include/grub/net/arp.h \
     .././include/grub/net/ethernet.h \
     .././include/grub/net.h \
     .././include/grub/net/ip.h \
     .././include/grub/net/netbuff.h \
     .././include/grub/net/tcp.h \
     .././include/grub/net/udp.h \
     .././include/grub/normal.h \
     .././include/grub/ns8250.h \
     .././include/grub/ntfs.h \
     .././include/grub/offsets.h \
     .././include/grub/parser.h \
     .././include/grub/partition.h \
     .././include/grub/parttool.h \
     .././include/grub/pci.h \
     .././include/grub/pciutils.h \
     .././include/grub/powerpc/ieee1275/ieee1275.h \
     .././include/grub/powerpc/kernel.h \
     .././include/grub/powerpc/memory.h \
     .././include/grub/powerpc/relocator.h \
     .././include/grub/powerpc/setjmp.h \
     .././include/grub/powerpc/time.h \
     .././include/grub/powerpc/types.h \
     .././include/grub/priority_queue.h \
     .././include/grub/reader.h \
     .././include/grub/reed_solomon.h \
     .././include/grub/relocator.h \
     .././include/grub/relocator_private.h \
     .././include/grub/script_sh.h \
     .././include/grub/scsicmd.h \
     .././include/grub/scsi.h \
     .././include/grub/sdl.h \
     .././include/grub/search.h \
     .././include/grub/serial.h \
     .././include/grub/setjmp.h \
     .././include/grub/smbus.h \
     .././include/grub/sparc64/ieee1275/boot.h \
     .././include/grub/sparc64/ieee1275/ieee1275.h \
     .././include/grub/sparc64/ieee1275/kernel.h \
     .././include/grub/sparc64/setjmp.h \
     .././include/grub/sparc64/time.h \
     .././include/grub/sparc64/types.h \
     .././include/grub/symbol.h \
     .././include/grub/term.h \
     .././include/grub/terminfo.h \
     .././include/grub/test.h \
     .././include/grub/time.h \
     .././include/grub/tparm.h \
     .././include/grub/trig.h \
     .././include/grub/types.h \
     .././include/grub/unicode.h \
     .././include/grub/usbdesc.h \
     .././include/grub/usb.h \
     .././include/grub/usbserial.h \
     .././include/grub/usbtrans.h \
     .././include/grub/util/libnvpair.h \
     .././include/grub/util/libzfs.h \
     .././include/grub/util/lvm.h \
     .././include/grub/util/misc.h \
     .././include/grub/util/ofpath.h \
     .././include/grub/util/resolve.h \
     .././include/grub/vga.h \
     .././include/grub/video_fb.h \
     .././include/grub/video.h \
     .././include/grub/x86_64/at_keyboard.h \
     .././include/grub/x86_64/efi/boot.h \
     .././include/grub/x86_64/efi/loader.h \
     .././include/grub/x86_64/efi/memory.h \
     .././include/grub/x86_64/efi/serial.h \
     .././include/grub/x86_64/io.h \
     .././include/grub/x86_64/linux.h \
     .././include/grub/x86_64/macho.h \
     .././include/grub/x86_64/memory.h \
     .././include/grub/x86_64/multiboot.h \
     .././include/grub/x86_64/pci.h \
     .././include/grub/x86_64/relocator.h \
     .././include/grub/x86_64/setjmp.h \
     .././include/grub/x86_64/time.h \
     .././include/grub/x86_64/types.h \
     .././include/grub/x86_64/xnu.h \
     .././include/grub/xnu.h \
     .././include/grub/zfs/dmu.h \
     .././include/grub/zfs/dmu_objset.h \
     .././include/grub/zfs/dnode.h \
     .././include/grub/zfs/dsl_dataset.h \
     .././include/grub/zfs/dsl_dir.h \
     .././include/grub/zfs/sa_impl.h \
     .././include/grub/zfs/spa.h \
     .././include/grub/zfs/uberblock_impl.h \
     .././include/grub/zfs/vdev_impl.h \
     .././include/grub/zfs/zap_impl.h \
     .././include/grub/zfs/zap_leaf.h \
     .././include/grub/zfs/zfs_acl.h \
     .././include/grub/zfs/zfs.h \
     .././include/grub/zfs/zfs_znode.h \
     .././include/grub/zfs/zil.h \
     .././include/grub/zfs/zio_checksum.h \
     .././include/grub/zfs/zio.h \
     .././include/multiboot2.h \
     .././include/multiboot.h \
     .././tests/cmp_unit_test.c \
     .././tests/example_unit_test.c \
     .././tests/lib/unit_test.c \
     .././tests/printf_unit_test.c \
     .././util/bin2h.c \
     .././util/getroot.c \
     .././util/grub-editenv.c \
     .././util/grub-fstest.c \
     .././util/grub-macho2img.c \
     .././util/grub-menulst2cfg.c \
     .././util/grub-mkfont.c \
     .././util/grub-mkimage.c \
     .././util/grub-mkimagexx.c \
     .././util/grub-mklayout.c \
     .././util/grub-mkpasswd-pbkdf2.c \
     .././util/grub-mkrelpath.c \
     .././util/grub-mount.c \
     .././util/grub-pe2elf.c \
     .././util/grub-probe.c \
     .././util/grub-script-check.c \
     .././util/grub-setup.c \
     .././util/ieee1275/grub-ofpathname.c \
     .././util/ieee1275/ofpath.c \
     .././util/lvm.c \
     .././util/misc.c \
     .././util/raid.c \
     .././util/resolve.c

CATALOGS =  ast.gmo ca.gmo da.gmo de.gmo de_CH.gmo de@hebrew.gmo en@arabic.gmo en@cyrillic.gmo en@greek.gmo en@hebrew.gmo en@piglatin.gmo en@quot.gmo eo.gmo fi.gmo fr.gmo hu.gmo id.gmo it.gmo ja.gmo nl.gmo pa.gmo pl.gmo ru.gmo sv.gmo uk.gmo vi.gmo zh_CN.gmo zh_TW.gmo

# Makevars gets inserted here. (Don't remove this line!)
# Makefile variables for PO directory in any package using GNU gettext.

# Usually the message domain is the same as the package name.
DOMAIN = $(PACKAGE)

# These two variables depend on the location of this directory.
subdir = po
top_builddir = ..

# These options get passed to xgettext.
XGETTEXT_OPTIONS = --keyword=_ --keyword=N_

# This is the copyright holder that gets inserted into the header of the
# $(DOMAIN).pot file.  Set this to the copyright holder of the surrounding
# package.  (Note that the msgstr strings, extracted from the package's
# sources, belong to the copyright holder of the package.)  Translators are
# expected to transfer the copyright for their translations to this person
# or entity, or to disclaim their copyright.  The empty string stands for
# the public domain; in this case the translators are expected to disclaim
# their copyright.
COPYRIGHT_HOLDER = Free Software Foundation, Inc.

# This is the email address or URL to which the translators shall report
# bugs in the untranslated strings:
# - Strings which are not entire sentences, see the maintainer guidelines
#   in the GNU gettext documentation, section 'Preparing Strings'.
# - Strings which use unclear terms or require additional context to be
#   understood.
# - Strings which make invalid assumptions about notation of date, time or
#   money.
# - Pluralisation problems.
# - Incorrect English spelling.
# - Incorrect formatting.
# It can be your email address, or a mailing list address where translators
# can write to without being subscribed, or the URL of a web page through
# which the translators can contact you.
MSGID_BUGS_ADDRESS = bug-grub@gnu.org

# This is the list of locale categories, beyond LC_MESSAGES, for which the
# message catalogs shall be used.  It is usually empty.
EXTRA_LOCALE_CATEGORIES =

.SUFFIXES:
.SUFFIXES: .po .gmo .mo .sed .sin .nop .po-create .po-update

.po.mo:
	@echo "$(MSGFMT) -c -o $@ $<"; \
	$(MSGFMT) --endianness=little -c -o t-$@ $< && mv t-$@ $@

.po.gmo:
	@lang=`echo $* | sed -e 's,.*/,,'`; \
	test "$(srcdir)" = . && cdcmd="" || cdcmd="cd $(srcdir) && "; \
	echo "$${cdcmd}rm -f $${lang}.gmo && $(GMSGFMT) --endianness=little -c --statistics --verbose -o $${lang}.gmo $${lang}.po"; \
	cd $(srcdir) && rm -f $${lang}.gmo && $(GMSGFMT) --endianness=little -c --statistics --verbose -o t-$${lang}.gmo $${lang}.po && mv t-$${lang}.gmo $${lang}.gmo

.sin.sed:
	sed -e '/^#/d' $< > t-$@
	mv t-$@ $@


all: check-macro-version all-yes

all-yes: stamp-po
all-no:

# Ensure that the gettext macros and this Makefile.in.in are in sync.
check-macro-version:
	@test "$(GETTEXT_MACRO_VERSION)" = "0.18" \
	  || { echo "*** error: gettext infrastructure mismatch: using a Makefile.in.in from gettext version $(GETTEXT_MACRO_VERSION) but the autoconf macros are from gettext version 0.18" 1>&2; \
	       exit 1; \
	     }

# $(srcdir)/$(DOMAIN).pot is only created when needed. When xgettext finds no
# internationalized messages, no $(srcdir)/$(DOMAIN).pot is created (because
# we don't want to bother translators with empty POT files). We assume that
# LINGUAS is empty in this case, i.e. $(POFILES) and $(GMOFILES) are empty.
# In this case, stamp-po is a nop (i.e. a phony target).

# stamp-po is a timestamp denoting the last time at which the CATALOGS have
# been loosely updated. Its purpose is that when a developer or translator
# checks out the package via CVS, and the $(DOMAIN).pot file is not in CVS,
# "make" will update the $(DOMAIN).pot and the $(CATALOGS), but subsequent
# invocations of "make" will do nothing. This timestamp would not be necessary
# if updating the $(CATALOGS) would always touch them; however, the rule for
# $(POFILES) has been designed to not touch files that don't need to be
# changed.
stamp-po: $(srcdir)/$(DOMAIN).pot
	test ! -f $(srcdir)/$(DOMAIN).pot || \
	  test -z "$(GMOFILES)" || $(MAKE) $(GMOFILES)
	@test ! -f $(srcdir)/$(DOMAIN).pot || { \
	  echo "touch stamp-po" && \
	  echo timestamp > stamp-poT && \
	  mv stamp-poT stamp-po; \
	}

# Note: Target 'all' must not depend on target '$(DOMAIN).pot-update',
# otherwise packages like GCC can not be built if only parts of the source
# have been downloaded.

# This target rebuilds $(DOMAIN).pot; it is an expensive operation.
# Note that $(DOMAIN).pot is not touched if it doesn't need to be changed.
$(DOMAIN).pot-update: $(POTFILES) $(srcdir)/POTFILES.in $(srcdir)/POTFILES-shell.in remove-potcdate.sed
	if LC_ALL=C grep 'GNU grub' $(top_srcdir)/* 2>/dev/null | grep -v 'libtool:' >/dev/null; then \
	  package_gnu='GNU '; \
	else \
	  package_gnu=''; \
	fi; \
	if test -n '$(MSGID_BUGS_ADDRESS)' || test '$(PACKAGE_BUGREPORT)' = '@'PACKAGE_BUGREPORT'@'; then \
	  msgid_bugs_address='$(MSGID_BUGS_ADDRESS)'; \
	else \
	  msgid_bugs_address='$(PACKAGE_BUGREPORT)'; \
	fi; \
	case `$(XGETTEXT) --version | sed 1q | sed -e 's,^[^0-9]*,,'` in \
	  '' | 0.[0-9] | 0.[0-9].* | 0.1[0-5] | 0.1[0-5].* | 0.16 | 0.16.[0-1]*) \
	    $(XGETTEXT) --default-domain=$(DOMAIN) --directory=$(top_srcdir) \
	      --add-comments=TRANSLATORS: $(XGETTEXT_OPTIONS)  --flag=argp_error:2:c-format --flag=argp_failure:4:c-format --flag=error:3:c-format --flag=error_at_line:5:c-format \
	      --files-from=$(srcdir)/POTFILES.in \
	      --copyright-holder='$(COPYRIGHT_HOLDER)' \
	      --msgid-bugs-address="$$msgid_bugs_address" \
	    ;; \
	  *) \
	    $(XGETTEXT) --default-domain=$(DOMAIN) --directory=$(top_srcdir) \
	      --add-comments=TRANSLATORS: $(XGETTEXT_OPTIONS)  --flag=argp_error:2:c-format --flag=argp_failure:4:c-format --flag=error:3:c-format --flag=error_at_line:5:c-format \
	      --files-from=$(srcdir)/POTFILES.in \
	      --copyright-holder='$(COPYRIGHT_HOLDER)' \
	      --package-name="$${package_gnu}grub" \
	      --package-version='2.00' \
	      --msgid-bugs-address="$$msgid_bugs_address" \
	    ;; \
	esac; \
	case `$(XGETTEXT) --version | sed 1q | sed -e 's,^[^0-9]*,,'` in \
	  '' | 0.[0-9] | 0.[0-9].* | 0.1[0-5] | 0.1[0-5].* | 0.16 | 0.16.[0-1]*) \
	    $(XGETTEXT) --default-domain=$(DOMAIN) --directory=$(top_srcdir) \
	      --add-comments=TRANSLATORS:  --flag=argp_error:2:c-format --flag=argp_failure:4:c-format --flag=error:3:c-format --flag=error_at_line:5:c-format \
	      --files-from=$(srcdir)/POTFILES-shell.in \
	      --copyright-holder='$(COPYRIGHT_HOLDER)' \
	      --msgid-bugs-address="$$msgid_bugs_address" \
	      --join-existing --language=Shell \
	      --keyword=gettext_quoted --keyword=gettext_printf \
	    ;; \
	  *) \
	    $(XGETTEXT) --default-domain=$(DOMAIN) --directory=$(top_srcdir) \
	      --add-comments=TRANSLATORS:  --flag=argp_error:2:c-format --flag=argp_failure:4:c-format --flag=error:3:c-format --flag=error_at_line:5:c-format \
	      --files-from=$(srcdir)/POTFILES-shell.in \
	      --copyright-holder='$(COPYRIGHT_HOLDER)' \
	      --package-name="$${package_gnu}grub" \
	      --package-version='2.00' \
	      --msgid-bugs-address="$$msgid_bugs_address" \
	      --join-existing --language=Shell \
	      --keyword=gettext_quoted --keyword=gettext_printf \
	    ;; \
	esac ; \
	test ! -f $(DOMAIN).po || { \
	  sed -f grub.d.sed < $(DOMAIN).po > $(DOMAIN).1po && \
	  mv $(DOMAIN).1po $(DOMAIN).po; \
	  if test -f $(srcdir)/$(DOMAIN).pot; then \
	    sed -f remove-potcdate.sed < $(srcdir)/$(DOMAIN).pot > $(DOMAIN).1po && \
	    sed -f remove-potcdate.sed < $(DOMAIN).po > $(DOMAIN).2po && \
	    if cmp $(DOMAIN).1po $(DOMAIN).2po >/dev/null 2>&1; then \
	      rm -f $(DOMAIN).1po $(DOMAIN).2po $(DOMAIN).po; \
	    else \
	      rm -f $(DOMAIN).1po $(DOMAIN).2po $(srcdir)/$(DOMAIN).pot && \
	      mv $(DOMAIN).po $(srcdir)/$(DOMAIN).pot; \
	    fi; \
	  else \
	    mv $(DOMAIN).po $(srcdir)/$(DOMAIN).pot; \
	  fi; \
	}

# This rule has no dependencies: we don't need to update $(DOMAIN).pot at
# every "make" invocation, only create it when it is missing.
# Only "make $(DOMAIN).pot-update" or "make dist" will force an update.
$(srcdir)/$(DOMAIN).pot:
	$(MAKE) $(DOMAIN).pot-update

# This target rebuilds a PO file if $(DOMAIN).pot has changed.
# Note that a PO file is not touched if it doesn't need to be changed.
$(POFILES): $(srcdir)/$(DOMAIN).pot
	@lang=`echo $@ | sed -e 's,.*/,,' -e 's/\.po$$//'`; \
	if test -f "$(srcdir)/$${lang}.po"; then \
	  test "$(srcdir)" = . && cdcmd="" || cdcmd="cd $(srcdir) && "; \
	  echo "$${cdcmd}$(MSGMERGE_UPDATE) $(MSGMERGE_OPTIONS) --lang=$${lang} $${lang}.po $(DOMAIN).pot"; \
	  cd $(srcdir) \
	    && { case `$(MSGMERGE_UPDATE) --version | sed 1q | sed -e 's,^[^0-9]*,,'` in \
	           '' | 0.[0-9] | 0.[0-9].* | 0.1[0-7] | 0.1[0-7].*) \
	             $(MSGMERGE_UPDATE) $(MSGMERGE_OPTIONS) $${lang}.po $(DOMAIN).pot;; \
	           *) \
	             $(MSGMERGE_UPDATE) $(MSGMERGE_OPTIONS) --lang=$${lang} $${lang}.po $(DOMAIN).pot;; \
	         esac; \
	       }; \
	else \
	  $(MAKE) $${lang}.po-create; \
	fi


install: install-exec install-data
install-exec:
install-data: install-data-yes
	if test "$(PACKAGE)" = "gettext-tools"; then \
	  $(mkdir_p) $(DESTDIR)$(gettextsrcdir); \
	  for file in $(DISTFILES.common) Makevars.template; do \
	    $(INSTALL_DATA) $(srcdir)/$$file \
			    $(DESTDIR)$(gettextsrcdir)/$$file; \
	  done; \
	  for file in Makevars; do \
	    rm -f $(DESTDIR)$(gettextsrcdir)/$$file; \
	  done; \
	else \
	  : ; \
	fi
install-data-no: all
install-data-yes: all
	@catalogs='$(CATALOGS)'; \
	for cat in $$catalogs; do \
	  cat=`basename $$cat`; \
	  lang=`echo $$cat | sed -e 's/\.gmo$$//'`; \
	  dir=$(localedir)/$$lang/LC_MESSAGES; \
	  $(mkdir_p) $(DESTDIR)$$dir; \
	  if test -r $$cat; then realcat=$$cat; else realcat=$(srcdir)/$$cat; fi; \
	  $(INSTALL_DATA) $$realcat $(DESTDIR)$$dir/$(DOMAIN).mo; \
	  echo "installing $$realcat as $(DESTDIR)$$dir/$(DOMAIN).mo"; \
	  for lc in '' $(EXTRA_LOCALE_CATEGORIES); do \
	    if test -n "$$lc"; then \
	      if (cd $(DESTDIR)$(localedir)/$$lang && LC_ALL=C ls -l -d $$lc 2>/dev/null) | grep ' -> ' >/dev/null; then \
	        link=`cd $(DESTDIR)$(localedir)/$$lang && LC_ALL=C ls -l -d $$lc | sed -e 's/^.* -> //'`; \
	        mv $(DESTDIR)$(localedir)/$$lang/$$lc $(DESTDIR)$(localedir)/$$lang/$$lc.old; \
	        mkdir $(DESTDIR)$(localedir)/$$lang/$$lc; \
	        (cd $(DESTDIR)$(localedir)/$$lang/$$lc.old && \
	         for file in *; do \
	           if test -f $$file; then \
	             ln -s ../$$link/$$file $(DESTDIR)$(localedir)/$$lang/$$lc/$$file; \
	           fi; \
	         done); \
	        rm -f $(DESTDIR)$(localedir)/$$lang/$$lc.old; \
	      else \
	        if test -d $(DESTDIR)$(localedir)/$$lang/$$lc; then \
	          :; \
	        else \
	          rm -f $(DESTDIR)$(localedir)/$$lang/$$lc; \
	          mkdir $(DESTDIR)$(localedir)/$$lang/$$lc; \
	        fi; \
	      fi; \
	      rm -f $(DESTDIR)$(localedir)/$$lang/$$lc/$(DOMAIN).mo; \
	      ln -s ../LC_MESSAGES/$(DOMAIN).mo $(DESTDIR)$(localedir)/$$lang/$$lc/$(DOMAIN).mo 2>/dev/null || \
	      ln $(DESTDIR)$(localedir)/$$lang/LC_MESSAGES/$(DOMAIN).mo $(DESTDIR)$(localedir)/$$lang/$$lc/$(DOMAIN).mo 2>/dev/null || \
	      cp -p $(DESTDIR)$(localedir)/$$lang/LC_MESSAGES/$(DOMAIN).mo $(DESTDIR)$(localedir)/$$lang/$$lc/$(DOMAIN).mo; \
	      echo "installing $$realcat link as $(DESTDIR)$(localedir)/$$lang/$$lc/$(DOMAIN).mo"; \
	    fi; \
	  done; \
	done

install-strip: install

installdirs: installdirs-exec installdirs-data
installdirs-exec:
installdirs-data: installdirs-data-yes
	if test "$(PACKAGE)" = "gettext-tools"; then \
	  $(mkdir_p) $(DESTDIR)$(gettextsrcdir); \
	else \
	  : ; \
	fi
installdirs-data-no:
installdirs-data-yes:
	@catalogs='$(CATALOGS)'; \
	for cat in $$catalogs; do \
	  cat=`basename $$cat`; \
	  lang=`echo $$cat | sed -e 's/\.gmo$$//'`; \
	  dir=$(localedir)/$$lang/LC_MESSAGES; \
	  $(mkdir_p) $(DESTDIR)$$dir; \
	  for lc in '' $(EXTRA_LOCALE_CATEGORIES); do \
	    if test -n "$$lc"; then \
	      if (cd $(DESTDIR)$(localedir)/$$lang && LC_ALL=C ls -l -d $$lc 2>/dev/null) | grep ' -> ' >/dev/null; then \
	        link=`cd $(DESTDIR)$(localedir)/$$lang && LC_ALL=C ls -l -d $$lc | sed -e 's/^.* -> //'`; \
	        mv $(DESTDIR)$(localedir)/$$lang/$$lc $(DESTDIR)$(localedir)/$$lang/$$lc.old; \
	        mkdir $(DESTDIR)$(localedir)/$$lang/$$lc; \
	        (cd $(DESTDIR)$(localedir)/$$lang/$$lc.old && \
	         for file in *; do \
	           if test -f $$file; then \
	             ln -s ../$$link/$$file $(DESTDIR)$(localedir)/$$lang/$$lc/$$file; \
	           fi; \
	         done); \
	        rm -f $(DESTDIR)$(localedir)/$$lang/$$lc.old; \
	      else \
	        if test -d $(DESTDIR)$(localedir)/$$lang/$$lc; then \
	          :; \
	        else \
	          rm -f $(DESTDIR)$(localedir)/$$lang/$$lc; \
	          mkdir $(DESTDIR)$(localedir)/$$lang/$$lc; \
	        fi; \
	      fi; \
	    fi; \
	  done; \
	done

# Define this as empty until I found a useful application.
installcheck:

uninstall: uninstall-exec uninstall-data
uninstall-exec:
uninstall-data: uninstall-data-yes
	if test "$(PACKAGE)" = "gettext-tools"; then \
	  for file in $(DISTFILES.common) Makevars.template; do \
	    rm -f $(DESTDIR)$(gettextsrcdir)/$$file; \
	  done; \
	else \
	  : ; \
	fi
uninstall-data-no:
uninstall-data-yes:
	catalogs='$(CATALOGS)'; \
	for cat in $$catalogs; do \
	  cat=`basename $$cat`; \
	  lang=`echo $$cat | sed -e 's/\.gmo$$//'`; \
	  for lc in LC_MESSAGES $(EXTRA_LOCALE_CATEGORIES); do \
	    rm -f $(DESTDIR)$(localedir)/$$lang/$$lc/$(DOMAIN).mo; \
	  done; \
	done

check: all

info dvi ps pdf html tags TAGS ctags CTAGS ID:

mostlyclean:
	rm -f remove-potcdate.sed
	rm -f stamp-poT
	rm -f core core.* $(DOMAIN).po $(DOMAIN).1po $(DOMAIN).2po *.new.po
	rm -fr *.o

clean: mostlyclean

distclean: clean
	rm -f Makefile Makefile.in POTFILES *.mo

maintainer-clean: distclean
	@echo "This command is intended for maintainers to use;"
	@echo "it deletes files that may require special tools to rebuild."
	rm -f stamp-po $(GMOFILES)

distdir = $(top_builddir)/$(PACKAGE)-$(VERSION)/$(subdir)
dist distdir:
	$(MAKE) update-po
	@$(MAKE) dist2
# This is a separate target because 'update-po' must be executed before.
dist2: stamp-po $(DISTFILES)
	dists="$(DISTFILES)"; \
	if test "$(PACKAGE)" = "gettext-tools"; then \
	  dists="$$dists Makevars.template"; \
	fi; \
	if test -f $(srcdir)/$(DOMAIN).pot; then \
	  dists="$$dists $(DOMAIN).pot stamp-po"; \
	fi; \
	if test -f $(srcdir)/ChangeLog; then \
	  dists="$$dists ChangeLog"; \
	fi; \
	for i in 0 1 2 3 4 5 6 7 8 9; do \
	  if test -f $(srcdir)/ChangeLog.$$i; then \
	    dists="$$dists ChangeLog.$$i"; \
	  fi; \
	done; \
	if test -f $(srcdir)/LINGUAS; then dists="$$dists LINGUAS"; fi; \
	for file in $$dists; do \
	  if test -f $$file; then \
	    cp -p $$file $(distdir) || exit 1; \
	  else \
	    cp -p $(srcdir)/$$file $(distdir) || exit 1; \
	  fi; \
	done

update-po: Makefile
	$(MAKE) $(DOMAIN).pot-update
	test -z "$(UPDATEPOFILES)" || $(MAKE) $(UPDATEPOFILES)
	$(MAKE) update-gmo

# General rule for creating PO files.

.nop.po-create:
	@lang=`echo $@ | sed -e 's/\.po-create$$//'`; \
	echo "File $$lang.po does not exist. If you are a translator, you can create it through 'msginit'." 1>&2; \
	exit 1

# General rule for updating PO files.

.nop.po-update:
	@lang=`echo $@ | sed -e 's/\.po-update$$//'`; \
	if test "$(PACKAGE)" = "gettext-tools"; then PATH=`pwd`/../src:$$PATH; fi; \
	tmpdir=`pwd`; \
	echo "$$lang:"; \
	test "$(srcdir)" = . && cdcmd="" || cdcmd="cd $(srcdir) && "; \
	echo "$${cdcmd}$(MSGMERGE) $(MSGMERGE_OPTIONS) --lang=$$lang $$lang.po $(DOMAIN).pot -o $$lang.new.po"; \
	cd $(srcdir); \
	if { case `$(MSGMERGE) --version | sed 1q | sed -e 's,^[^0-9]*,,'` in \
	       '' | 0.[0-9] | 0.[0-9].* | 0.1[0-7] | 0.1[0-7].*) \
	         $(MSGMERGE) $(MSGMERGE_OPTIONS) -o $$tmpdir/$$lang.new.po $$lang.po $(DOMAIN).pot;; \
	       *) \
	         $(MSGMERGE) $(MSGMERGE_OPTIONS) --lang=$$lang -o $$tmpdir/$$lang.new.po $$lang.po $(DOMAIN).pot;; \
	     esac; \
	   }; then \
	  if cmp $$lang.po $$tmpdir/$$lang.new.po >/dev/null 2>&1; then \
	    rm -f $$tmpdir/$$lang.new.po; \
	  else \
	    if mv -f $$tmpdir/$$lang.new.po $$lang.po; then \
	      :; \
	    else \
	      echo "msgmerge for $$lang.po failed: cannot move $$tmpdir/$$lang.new.po to $$lang.po" 1>&2; \
	      exit 1; \
	    fi; \
	  fi; \
	else \
	  echo "msgmerge for $$lang.po failed!" 1>&2; \
	  rm -f $$tmpdir/$$lang.new.po; \
	fi

$(DUMMYPOFILES):

update-gmo: Makefile $(GMOFILES)
	@:

# Recreate Makefile by invoking config.status. Explicitly invoke the shell,
# because execution permission bits may not work on the current file system.
# Use /bin/bash, which is the shell determined by autoconf for the use by its
# scripts, not $(SHELL) which is hardwired to /bin/sh and may be deficient.
Makefile: Makefile.in.in Makevars $(top_builddir)/config.status POTFILES.in LINGUAS
	cd $(top_builddir) \
	  && /bin/bash ./config.status $(subdir)/$@.in po-directories

force:

# Tell versions [3.59,3.63) of GNU make not to export all variables.
# Otherwise a system limit (for SysV at least) may be exceeded.
.NOEXPORT:
# Special Makefile rules for Pig Latin message catalogs with quotation marks.

DISTFILES.common.extra3 = piglatin.sed en@piglatin.header insert-header.sin Rules-piglatin

.SUFFIXES: .insert-header .po-update-en-piglatin

en@piglatin.po-create:
	$(MAKE) en@piglatin.po-update

en@piglatin.po-update: en@piglatin.po-update-en

.insert-header.po-update-en-piglatin:
	@lang=`echo $@ | sed -e 's/\.po-update-en-piglatin$$//'`; \
	if test "$(PACKAGE)" = "gettext"; then PATH=`pwd`/../src:$$PATH; GETTEXTLIBDIR=`cd $(top_srcdir)/src && pwd`; export GETTEXTLIBDIR; fi; \
	tmpdir=`pwd`; \
	echo "$$lang:"; \
	ll=`echo $$lang | sed -e 's/@.*//'`; \
	LC_ALL=C; export LC_ALL; \
	cd $(srcdir); \
	if $(MSGINIT) -i $(DOMAIN).pot --no-translator -l $$lang -o - 2>/dev/null | sed -f $$tmpdir/$$lang.insert-header | $(MSGCONV) -t UTF-8 | $(MSGFILTER) sed -f `echo $$lang | sed -e 's/.*@//'`.sed 2>/dev/null > $$tmpdir/$$lang.new.po; then \
	  if cmp $$lang.po $$tmpdir/$$lang.new.po >/dev/null 2>&1; then \
	    rm -f $$tmpdir/$$lang.new.po; \
	  else \
	    if mv -f $$tmpdir/$$lang.new.po $$lang.po; then \
	      :; \
	    else \
	      echo "creation of $$lang.po failed: cannot move $$tmpdir/$$lang.new.po to $$lang.po" 1>&2; \
	      exit 1; \
	    fi; \
	  fi; \
	else \
	  echo "creation of $$lang.po failed!" 1>&2; \
	  rm -f $$tmpdir/$$lang.new.po; \
	fi

en@piglatin.insert-header: insert-header.sin
	sed -e '/^#/d' -e 's/HEADER/en@piglatin.header/g' $(srcdir)/insert-header.sin > en@piglatin.insert-header

mostlyclean: mostlyclean-piglatin
mostlyclean-piglatin:
	rm -f *.insert-header
# Special Makefile rules for English message catalogs with quotation marks.

DISTFILES.common.extra1 = quot.sed boldquot.sed en@quot.header en@boldquot.header insert-header.sin Rules-quot

.SUFFIXES: .insert-header .po-update-en

en@quot.po-create:
	$(MAKE) en@quot.po-update
en@boldquot.po-create:
	$(MAKE) en@boldquot.po-update

en@quot.po-update: en@quot.po-update-en
en@boldquot.po-update: en@boldquot.po-update-en

.insert-header.po-update-en:
	@lang=`echo $@ | sed -e 's/\.po-update-en$$//'`; \
	if test "$(PACKAGE)" = "gettext"; then PATH=`pwd`/../src:$$PATH; GETTEXTLIBDIR=`cd $(top_srcdir)/src && pwd`; export GETTEXTLIBDIR; fi; \
	tmpdir=`pwd`; \
	echo "$$lang:"; \
	ll=`echo $$lang | sed -e 's/@.*//'`; \
	LC_ALL=C; export LC_ALL; \
	cd $(srcdir); \
	if $(MSGINIT) -i $(DOMAIN).pot --no-translator -l $$lang -o - 2>/dev/null | sed -f $$tmpdir/$$lang.insert-header | $(MSGCONV) -t UTF-8 | $(MSGFILTER) sed -f `echo $$lang | sed -e 's/.*@//'`.sed 2>/dev/null > $$tmpdir/$$lang.new.po; then \
	  if cmp $$lang.po $$tmpdir/$$lang.new.po >/dev/null 2>&1; then \
	    rm -f $$tmpdir/$$lang.new.po; \
	  else \
	    if mv -f $$tmpdir/$$lang.new.po $$lang.po; then \
	      :; \
	    else \
	      echo "creation of $$lang.po failed: cannot move $$tmpdir/$$lang.new.po to $$lang.po" 1>&2; \
	      exit 1; \
	    fi; \
	  fi; \
	else \
	  echo "creation of $$lang.po failed!" 1>&2; \
	  rm -f $$tmpdir/$$lang.new.po; \
	fi

en@quot.insert-header: insert-header.sin
	sed -e '/^#/d' -e 's/HEADER/en@quot.header/g' $(srcdir)/insert-header.sin > en@quot.insert-header

en@boldquot.insert-header: insert-header.sin
	sed -e '/^#/d' -e 's/HEADER/en@boldquot.header/g' $(srcdir)/insert-header.sin > en@boldquot.insert-header

mostlyclean: mostlyclean-quot
mostlyclean-quot:
	rm -f *.insert-header
# Special Makefile rules for transforming German typography into Swiss one.

DISTFILES.common.extra2 = swiss.sed Rules-swiss

de_CH.po-create: de.po swiss.sed
	LC_ALL=C.UTF-8 $(MSGFILTER) -i $< -o $(srcdir)/de_CH.po sed -f $(srcdir)/swiss.sed

DISTFILES.common.extra4 = hebrew.sed cyrillic.sed greek.sed arabic.sed Rules-translit

de@hebrew.po-create: de.po hebrew.sed
	LC_ALL=C.UTF-8 $(MSGFILTER) -i $< -o $(srcdir)/de@hebrew.po sed -f $(srcdir)/hebrew.sed

en@hebrew.po-create: $(DOMAIN).pot hebrew.sed
	LC_ALL=C.UTF-8 $(MSGINIT) -i $(srcdir)/$(DOMAIN).pot --no-translator -l en@hebrew -o - 2>/dev/null | LC_ALL=C.UTF-8 $(MSGCONV) -t UTF-8 | LC_ALL=C.UTF-8 $(MSGFILTER) -o $(srcdir)/en@hebrew.po -i - sed -f $(srcdir)/hebrew.sed

en@cyrillic.po-create: $(DOMAIN).pot cyrillic.sed
	LC_ALL=C.UTF-8 $(MSGINIT) -i $(srcdir)/$(DOMAIN).pot --no-translator -l en@cyrillic -o - 2>/dev/null | LC_ALL=C.UTF-8 $(MSGCONV) -t UTF-8 | LC_ALL=C.UTF-8 $(MSGFILTER) -o $(srcdir)/en@cyrillic.po -i - sed -f $(srcdir)/cyrillic.sed

en@greek.po-create: $(DOMAIN).pot greek.sed
	LC_ALL=C.UTF-8 $(MSGINIT) -i $(srcdir)/$(DOMAIN).pot --no-translator -l en@greek -o - 2>/dev/null | LC_ALL=C.UTF-8 $(MSGCONV) -t UTF-8 | LC_ALL=C.UTF-8 $(MSGFILTER) -o $(srcdir)/en@greek.po -i - sed -f $(srcdir)/greek.sed

en@arabic.po-create: $(DOMAIN).pot arabic.sed
	LC_ALL=C.UTF-8 $(MSGINIT) -i $(srcdir)/$(DOMAIN).pot --no-translator -l en@arabic -o - 2>/dev/null | LC_ALL=C.UTF-8 $(MSGCONV) -t UTF-8 | LC_ALL=C.UTF-8 $(MSGFILTER) -o $(srcdir)/en@arabic.po -i - sed -f $(srcdir)/arabic.sed
